package org.jabber.jabbermeister;

import java.applet.*;
import java.awt.*;
import java.awt.event.*;

class LoginDialog
    extends Dialog 
    implements ActionListener
{

    /**
     * String holding the server name. Passed in from the main client
     * if it is an applet or the programmer wishes to restrict accessable 
     * servers
     */
    private java.net.InetAddress server=null;

    private boolean id=false;
    private Button ok,cancel;
    private TextField username=null;
    private TextField serverName=null;
    private TextField resource=null;
    private TextField password=null;

    /**
     * Constructor which takes an owner and a server name.
     *
     * @param owner parent 'Frame'
     * @param serverName server name in an InetAddress
     */
    LoginDialog(Frame owner, java.net.InetAddress server)
    {
	super(owner,"Please enter Login information",true);
	this.server=server;
	setupDialog();
    }

    /**
     * Constructor which only takes an owner. The server name is left open
     *
     * @param owner parent 'Frame'
     */
    LoginDialog(Frame owner)
    { 
	super(owner,"Please enter Login information",true);
	this.server=null;
	setupDialog();
    }

    void setupDialog()
    {
	setLayout(new BorderLayout());
	username = new TextField(8);
	serverName = new TextField(16);
	if (server != null)
	    {
		//if we have the server object, fill in servername
		serverName.setText(server.getHostName());
		//..then disable the field
		serverName.setEnabled(false);
	    }
	resource = new TextField(8);
	password = new TextField(8);
	password.setEchoChar('*');
	
	Panel p=new Panel();
	p.setLayout(new FlowLayout(FlowLayout.CENTER,0,0));
	p.add(new Label("URI (user@server/nick):"));
	p.add(username);
	p.add(new Label("@"));
	p.add(serverName);
	p.add(new Label("/"));
	p.add(resource);
	add(p,BorderLayout.NORTH);

	p=new Panel();
	p.setLayout(new FlowLayout(FlowLayout.CENTER,0,0));	
	p.add(new Label("Password :"));
	p.add(password);
	add(p,BorderLayout.CENTER);
	addOKCancelPanel();
	createFrame();
	pack();
	setVisible(true);
    }

    void addOKCancelPanel() {
	Panel p = new Panel();
	p.setLayout(new FlowLayout());
	createButtons( p );
	add( p,BorderLayout.SOUTH );
    }
    
    void createButtons(Panel p) {
	p.add(ok = new Button("OK"));
	ok.addActionListener(this); 
	p.add(cancel = new Button("Cancel"));
	cancel.addActionListener(this);
    }
    
    void createFrame() {
	Dimension d = getToolkit().getScreenSize();
	setLocation(d.width/4,d.height/3);
    }    

    boolean getID() 
    {
	return id;
    }

    String getServer()
    {
	return serverName.getText();
    }

    String getURI()
    {
	return "jabber:"+username.getText()+"@"+serverName.getText()
	    +"/"+resource.getText();
    }
    String getPassword()
    {
	return password.getText();
    }

    public void actionPerformed(ActionEvent ae){
	if(ae.getSource() == ok) {
	    id = true;
	    setVisible(false);
	}
	else if(ae.getSource() == cancel) {
	    setVisible(false);
	}
    }
}
