/*
 * BrowseBean.java
 *
 * Created on January 1, 2002, 5:34 PM
 */


package org.jabber.jabberbeans;


import java.io.*;
import java.util.*;//Vector;
import org.jabber.jabberbeans.*;
import org.jabber.jabberbeans.util.*;
import org.jabber.jabberbeans.Extension.*;


/**
 *
 * @author  Shawn
 */


public class BrowseBean implements Serializable
{
	ConnectionBean cb = null;
	Vector browseListeners = null;
	Hashtable cache = null;
	boolean debug = false;
	
	BrowsePacketListener packetListener = new BrowsePacketListener();
	
	//Constructor
	/*
	 *<code>BrowseBean</code> the do nothing constructor
	 */
	public BrowseBean(){reset();}
	
	
	/*
	 *<code>reset</code> resets the fields in the object
	 */
	public void reset()
	{
		browseListeners = new Vector();
		cache = new Hashtable();						
		debug = false;
	}
	
	/*
	 * <code>setDebug</code> set the debug state of the bean
	 *
	 * @param value <code>boolean</code> state
	 */
	public void setDebug(boolean value)
	{debug = value;}
	
	/*
	 * <code>getDebug</code> get the debug state of the bean
	 *
	 * @return <code>boolean</code> is the state of debug
	 */
	public boolean getDebug()
	{return debug;}
	
	/*
	 * <code>setConnbean</code> set the connection bean
	 *
	 * @param con <code>ConnectionBean</code> connection bean to use
	 */
	public void setConnBean(ConnectionBean con)
	{
		if(cb != null)
			cb.delPacketListener(packetListener);
		cb = con;
		cb.addPacketListener(packetListener);
	}
	/*
	 * <code>getConnBean</code> get the connection bean being used
	 *
	 * @return <code>ConnectionBean</code> the connection bean being used
	 */
	public ConnectionBean getConnBean()
	{return cb;}
	
	
	/*
	 * <code>browseTo</code> 
	 * Note:  The packet id below is what is returned... Not what you set.. You may use null
	 *
	 * @param addy <code>JID</code> to browse to.
	 * @param <code>PacketID</code> packet id.
	 * @param refresh <code>boolean</code> whether or not to send a new request
	 */
	public void browseTo(String addy, PacketID id, boolean refresh)
	{browseTo(JID.fromString(addy), id, refresh);}	
	
	
	/*
	 * <code>browseTo</code> 
	 * Note:  The packet id below is what is returned... Not what you set.. You may use null
	 *
	 * @param addy <code>JID</code> to browse to.
	 * @param <code>PacketID</code> packet id.
	 * @param refresh <code>boolean</code> whether or not to send a new request
	 */
	public void browseTo(JID addy, PacketID id, boolean refresh)
	{
		if(addy == null)
			return;
		
		//If refresh is false, we check in the cache
		if(!refresh)
		{
			if(cache.containsKey(addy.toString()))
			{
				if(id != null)
					id.setID(((InfoQuery)cache.get(addy.toString())).getIdentifier());
				packetHandler((InfoQuery)cache.get(addy.toString()));				
			}
		}
		
		//If refresh is set, or the item is not in the cache, then we
		//attempt to send a browse to the JID specified
		try
		{
			InfoQueryBuilder iqb = new InfoQueryBuilder();
			InfoQuery iq = null;
			
			iqb.reset();
			iqb.setType("get");
			iqb.setToAddress(addy);

			IQBrowseBuilder browser = new IQBrowseBuilder();
			browser.reset();
			browser.setIQ(true);

			iqb.addExtension(browser.build());
			iq = (InfoQuery)iqb.build();
			if(id != null)
				id.setID(iq.getIdentifier());
			cb.send(iq);
		}
		catch(Exception e){e.printStackTrace(); return;}
	}
	
	
	public class BrowsePacketListener implements PacketListener
	{	
		/*
		 * called when a packet is received and processed.
		 *
		 * @param pe PacketEvent that has just been received.
		 */
		public void receivedPacket(PacketEvent pe)
		{
			//Return if it's not an IQ packet
			if(!(pe.getPacket() instanceof InfoQuery))
				return;
			
			//Type to an IQ packet
			InfoQuery iq = null;
			try{iq = (InfoQuery)pe.getPacket();}
			catch(Exception e){e.printStackTrace(); return;}

			packetHandler(iq);			
		}
	
		
		/*
		 * called if a packet is not successfully sent (for instance, if the connection
		 * dies while the packet is queued, or a packet is sent while disconnected).
		 *
		 * @param pe PacketEvent for the failed send
		 */
		public void sendFailed(PacketEvent pe)
		{
			if(debug)
				System.err.println("Browse packet failed to send");
		}
		
		
		/**
		 * called whenever a local client sends a packet, after the sending
		 * is successful
		 *
		 * @param pe PacketEvent that has just been sent
		 */
		public void sentPacket(PacketEvent pe)
		{
			if(debug)
				System.err.println("Browse packet sent");
		}
	}
	
	
	/*
	 * <code>packetHandler</code> takes a packet that was recieved (type=browse)
	 * and dismantles it then send down the browse item and the id to the event listener
	 *
	 * @param <code>Packet</code> p is the packet to pass down..
	 */
	public void packetHandler(InfoQuery iq)
	{
		//Grab the extensions in the packet
		Enumeration enum = null;
		try{enum = iq.Extensions();}
		catch(Exception e){e.printStackTrace(); return;}
		
		
		try
		{
			//Loop through all of the extensions in the packet
			while(enum.hasMoreElements())
			{
				//Grab an extension
				Object object = enum.nextElement();
				
				//If the extension object is a browse item, then we pass it to those listening
				if(object instanceof BrowseItem)
				{
					if(iq.getErrorCode() != null)
						fireError(iq, iq.getIdentifier());
					else
					{
						if(((BrowseItem)object).getJID() != null)
						{
							if(debug)
								System.err.println("Caching JID in BrowseBean:  " + ((BrowseItem)object).getJID().toString());
							cache.put(((BrowseItem)object).getJID().toString(), iq);
						}
						fireReceived((BrowseItem)object, iq.getIdentifier());
					}
				}
			}
		}
		catch(Exception e){e.printStackTrace();}
	}
	
	
	/**
	 * <code>addPacketListener</code> lets you register a <code>
	 * PacketListener</code> to receive connection state changes.
	 *
	 * @param l <code>PacketListener</code> to register
	 */
	public synchronized void addBrowseListener(BrowseListener l)
	{
		if(!browseListeners.contains(l))
			browseListeners.addElement(l);
	}
	
	
	/**
	 * <code>delPacketListener</code> lets you unregister a <code>
	 * PacketListener</code> that receives connection state changes.
	 *
	 * @param l <code>PacketListener</code> to unregister
	 */
	public synchronized void delBrowseListener(BrowseListener l)
	{			
		if(browseListeners.contains(l))
			browseListeners.removeElement(l);
	}
	
	/*
	 *<code>fireReceived</code> fires the received event
	 *
	 *@param b <code>BrowseItem</code> Browse Item to pass
	 */
	private void fireReceived(BrowseItem b, String id)
	{
		if(debug)
			System.err.println("Received event fired.");
		
		try
		{
			Vector broadcast = (Vector)browseListeners.clone();
			for(Enumeration e = broadcast.elements(); e.hasMoreElements();)
			((BrowseListener)e.nextElement()).received(b, id);
		}
		catch(Exception e)
		{e.printStackTrace();}
	}
	
	/*
	 *<code>fireError</code> fires the error event
	 *
	 *@param iq <code>BrowseItem</code> IQ packet to pass
	 */
	private void fireError(InfoQuery iq, String id)
	{
		if(debug)
			System.err.println("Error event fired.");
		
		try
		{
			Vector broadcast = (Vector)browseListeners.clone();
			for(Enumeration e = broadcast.elements(); e.hasMoreElements();)
			((BrowseListener)e.nextElement()).error(iq, id);
		}
		catch(Exception e)
		{e.printStackTrace();}
	}
}