/*
 *   License
 *
 * The contents of this file are subject to the Jabber Open Source License
 * Version 1.0 (the "License").  You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License.  You
 * may obtain a copy of the License at http://www.jabber.com/license/ or at
 * http://www.opensource.org/.  
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 *   Copyrights
 *
 * Portions created by or assigned to Jabber.com, Inc. are 
 * Copyright (c) 2000 Jabber.com, Inc.  All Rights Reserved.  Contact
 * information for Jabber.com, Inc. is available at http://www.jabber.com/.
 *
 * Portions Copyright (c) 1999-2000 David Waite 
 *
 *   Acknowledgements
 * 
 * Special thanks to the Jabber Open Source Contributors for their
 * suggestions and support of Jabber.
 * 
 *   Changes
 *
 */

package org.jabber.jabberbeans;

import java.io.Serializable;

/**
 * Convenience implementation of ConnectionListener. This is provided so that
 * the ConnectionListener interface can be upgraded, without breaking backwards
 * compatibility - extend ConnectionAdapter and you will gain do-nothing
 * implementations of ConnectionListener's new events.<p>
 * ConnectionListener contains descriptions of what these events actually 
 * signify.
 *
 * @author  David Waite <a href="mailto:dwaite@jabber.com">
 *                      <i>&lt;dwaite@jabber.com&gt;</i></a>
 * @author  $Author: mass $
 * @version $Revision: 1.14 $
 */

public class ConnectionAdapter
    implements ConnectionListener, Serializable
{
    /**
     * <code>connectionChanged</code> is the most recent way to receive
     * notification of a change in connection state. The implementation
     * here receives the event and broadcasts to the older deprecated
     * methods for the time being.
     *
     * @param evt a <code>ConnectionEvent</code> value
     */
    public void connectionChanged(ConnectionEvent evt)
    {
	switch (evt.getState().getValue())
	    {
	    case ConnectionEvent.EState.DISCONNECTED:
		if ( evt.getOldState() == 
		     ConnectionEvent.STATE_CONNECTING )
		    connectFailed(evt);
		else
		    disconnected(evt);
		break;
	    case ConnectionEvent.EState.CONNECTING:
		connecting(evt);
		break;
	    case ConnectionEvent.EState.CONNECTED:
		connected(evt);
		break;
	    default:
		throw new RuntimeException
		    ("Illegal Connection state imput to ConnectionAdapter");
	    }
    }	
    
    /** @deprecated  replaced by {@link #connectionChanged(ConnectionEvent)},
     *	will be removed before 1.0 */
    public void connected(ConnectionEvent evt)
    {
	connected();
    }

    /** @deprecated  replaced by {@link #connectionChanged(ConnectionEvent)},
     *	will be removed before 1.0 */
    public void disconnected(ConnectionEvent evt)
    {
	disconnected();
    }
    /** @deprecated  replaced by {@link #connectionChanged(ConnectionEvent)},
     *	will be removed before 1.0 */
    public void connecting(ConnectionEvent evt)
    {
	connecting();
    }
    /** @deprecated  replaced by {@link #connectionChanged(ConnectionEvent)},
     *	will be removed before 1.0 */
    public void connectFailed(ConnectionEvent evt)
    {
	connectFailed();
    };

    /** @deprecated  replaced by {@link #connectionChanged(ConnectionEvent)},
     *	will be removed before 1.0 */
    public void connected()
    {}

    /** @deprecated  replaced by {@link #connectionChanged(ConnectionEvent)},
     *	will be removed before 1.0 */
    public void disconnected()
    {}

    /** @deprecated  replaced by {@link #connectionChanged(ConnectionEvent)},
     *	will be removed before 1.0 */
    public void connecting()
    {}

    /** @deprecated  replaced by {@link #connectionChanged(ConnectionEvent)},
     *	will be removed before 1.0 */
    public void connectFailed()
    {}
}
