package org.jabber.jabberbeans.Extension;


import java.io.Serializable;
import java.util.*;
import org.jabber.jabberbeans.util.*;
import org.jabber.jabberbeans.*;
import org.jabber.jabberbeans.Extension.*;


/*
 * An <code>BrowseItemBuilder</code> is used to generate a jabber:iq:browse
 * namespace object, or one of its children.
 */

public class BrowseItemBuilder implements ExtensionBuilder
{
	/* whether item is an IQ object or not */
	private boolean iq;
	
	/** type of the browse item */
	private String category;

	/** subtype of the browse item */
	private String type;

	/** name given to this browse item */
	private String name;

	/** address this browse item refers to */
	private JID jid;

	private Vector namespaces;
	private Vector childItems; 

	/*
	 * Construct a new <code>BrowseItemBuilder</code> object 
	 */
	public BrowseItemBuilder()
	{reset();}

	/** reset this builder to a default state, for reuse */
	public void reset()
	{
		iq = false;
		category = null;
		type = null;
		name = null;
		jid = null;
		namespaces = new Vector();
		childItems = new Vector();
	}
	
	
	/* return the IQ item */
	public boolean isIQ()
	{return iq;}
	
	/* set the IQ item */
	public void setIQ(boolean value)
	{iq = value;}

	
	/** return the subtype of this item (represented by the type attribute) */
	public String getCategory()
	{return category;}

	/** set the subtype of this item (represented by the type attribute) */
	public void setCategory(String val)
	{category = val;}

	
	/** return the type of this item (represented by the element name) */
	public String getType()
	{return type;}

	/** set the type of this item (represented by the element name) */
	public void setType(String val)
	{type = val;}

	
	/** return a textual string for displaying this item */
	public String getName()
	{return name;}

	/** set a textual string for displaying this item */
	public void setName(String val)
	{name = val;}

	
	/** return the address this item refers to */
	public JID getJID()
	{return jid;}

	/** set the address this item refers to */
	public void setJID(JID val)
	{jid = val;}

	
	//Add a namespace
	public void addNameSpace(String str)
	{
		if(str != null && !namespaces.contains(str))
			namespaces.addElement(str);
	}
	
	//return the vector of namespaces
	public Vector getNameSpaces()
	{return namespaces;}

	//enumeration of namespaces
	public Enumeration namespaces()
	{return namespaces.elements();}
	
	
	//Add a Child item
	public void addChild(BrowseItem object)
	{
		if(object != null && !namespaces.contains(object))
			childItems.addElement(object);
	}
	
	//return the vector of children
	public Vector getChildren()
	{return childItems;}
	
	//return the enumeration of children
	public Enumeration children()
	{return childItems.elements();}
	
	
	/*
	 * Build a <code>BrowseItem Extension</code> based on the current builder
	 * state.
	 *
	 * @return <code>BrowseItem Extension</code> based on the current builder
	 * state.
	 */
	public Extension build() throws InstantiationException
	{return new BrowseItem(this);}
}