/*
 *   License
 *
 * The contents of this file are subject to the Jabber Open Source License
 * Version 1.0 (the "License").  You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License.  You
 * may obtain a copy of the License at http://www.jabber.com/license/ or at
 * http://www.opensource.org/.  
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 *   Copyrights
 *
 * Portions created by or assigned to Jabber.com, Inc. are 
 * Copyright (c) 2000 Jabber.com, Inc.  All Rights Reserved.  Contact
 * information for Jabber.com, Inc. is available at http://www.jabber.com/.
 *
 * Portions Copyright (c) 1999-2000 David Waite 
 *
 *   Acknowledgements
 * 
 * Special thanks to the Jabber Open Source Contributors for their
 * suggestions and support of Jabber.
 * 
 *   Changes
 *
 */

package org.jabber.jabberbeans.Extension;

import java.io.Serializable;

/** An <code>Extension</code> is the base interface for all <x xmlns="*"> and 
 * <query xmlns="*">type extensions on tags. Obejcts that implement Extension
 * should be immutable,  meaning that if the construction is overly complicated
 * a Builder object  should be used (for example, 
 * org.jabber.jabberbeans.Message
 * and org.jabber.jabberbeans.MessageBuilder).
 *
 * Extensions also need to be parsed, meaning that if the object needs 
 * to use an XML parser, that implementation of the Extension needs to 
 * have the associated parser. So there could be a DOM, a SAX, etc version of
 * the builder for a message extension; these would be packaged with the 
 * protocol handler (see jabberbeans-sax for examples)
 *
 * The interface uses toString() to export an XML representation of contained 
 * data, and uses the Serializable interface for an object-based representation
 * (if someone was to implement a non-XML based client-server arch)
 *
 * @author  David Waite <a href="mailto:dwaite@jabber.com">
 *                      <i>&lt;dwaite@jabber.com&gt;</i></a>
 * @author  $Author: mass $
 * @version $Revision: 1.10 $
 */

public interface Extension
    extends Serializable
{
    void appendItem(StringBuffer retval);
    String toString();
}
