/*
 *   License
 *
 * The contents of this file are subject to the Jabber Open Source License
 * Version 1.0 (the "License").  You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License.  You
 * may obtain a copy of the License at http://www.jabber.com/license/ or at
 * http://www.opensource.org/.  
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 *   Copyrights
 *
 * Portions created by or assigned to Jabber.com, Inc. are 
 * Copyright (c) 2000 Jabber.com, Inc.  All Rights Reserved.  Contact
 * information for Jabber.com, Inc. is available at http://www.jabber.com/.
 *
 * Portions Copyright (c) 1999-2000 David Waite 
 *
 *   Acknowledgements
 * 
 * Special thanks to the Jabber Open Source Contributors for their
 * suggestions and support of Jabber.
 * 
 *   Changes
 *
 */

package org.jabber.jabberbeans.Extension;

/** ExtensionBuilders are responsible for building a Extension-
 * derived object.
 *
 * Extension and ExtensionBuilder-derived objects are independant of XML 
 * parser.
 *
 * For examples on how to use a ExtensionBuilder, look at any of the
 * message builders inside of org.jabber.jabberbeans.sax, or  
 * org.jabber.jabberbeans.MessageBuilder and its interface with 
 * org.jabber.jabberbeans.Message, which this is based on
 *
 * @author  David Waite <a href="mailto:dwaite@jabber.com">
 *                      <i>&lt;dwaite@jabber.com&gt;</i></a>
 * @author  $Author: mass $
 * @version $Revision: 1.9 $
 */
public interface ExtensionBuilder
{
    /**
     * <code>build</code> generates an Extension-derived object based on the
     * current state of this ExtensionBuilder
     *
     * @return an <code>Extension</code> object
     * @exception InstantiationException if insufficient or malformed data is
     * present
     */
    Extension build()
        throws InstantiationException;

    /**
     * <code>reset</code> resets the interface for the builder to default
     * values, so that it may be reused.
     */
    void reset();
}
