/*
 *   License
 *
 * The contents of this file are subject to the Jabber Open Source License
 * Version 1.0 (the "License").  You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License.  You
 * may obtain a copy of the License at http://www.jabber.com/license/ or at
 * http://www.opensource.org/.  
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 *   Copyrights
 *
 * Portions created by or assigned to Jabber.com, Inc. are 
 * Copyright (c) 2000 Jabber.com, Inc.  All Rights Reserved.  Contact
 * information for Jabber.com, Inc. is available at http://www.jabber.com/.
 *
 * Portions Copyright (c) 1999-2000 David Waite 
 *
 *   Acknowledgements
 * 
 * Special thanks to the Jabber Open Source Contributors for their
 * suggestions and support of Jabber.
 * 
 *   Changes
 *
 */

package org.jabber.jabberbeans.Extension;

import java.util.Hashtable;
import java.util.Enumeration;
import org.jabber.jabberbeans.*;

/**
 * A <code>HashExtension</code> holds the code which is shared by several
 * other extensions, including the register extension and part of the search
 * extension implementation.
 *
 * NOTE: it is my personal hope that this general type of extension dies a 
 * horrible death at a later date, probably at the hand of XML forms.
 *
 * all parameters are subject to interpretation - the names are meant to be 
 * labels to editable text boxes, with instructions being broadcast on how to
 * use the interface.
 *
 * also note that the values do not have default states - <name/> is 
 * represented by name.equals(""), whereas name=null indicates the element 
 * is not present
 *
 * @author  David Waite <a href="mailto:dwaite@jabber.com">
 *                      <i>&lt;dwaite@jabber.com&gt;</i></a>
 * @author  $Author: mass $
 * @version $Revision: 1.8 $
 */
abstract class HashExtension
    extends XMLData
    implements Extension
{
    /** <code>entries</code> is a list of all name/value pairs. */
    private Hashtable entries;

    /** Creates a new <code>HashExtension</code> instance. */
    protected HashExtension(HashExtensionBuilder builder)
        throws InstantiationException
    {
        entries=new Hashtable();
        Hashtable builderTable=builder.getTable();

        Enumeration names=builderTable.keys();

        if (names==null)
            return; //empty roster
        
        while (names.hasMoreElements())
        {
            String name=(String)names.nextElement();
            String value=(String)builderTable.get(name);
            entries.put(name,value);
        }
    }

    /**
     * <code>getValue</code gets a value based on its name, or null if there
     * is no value associated with that name.
     *
     * @param name a <code>String</code> value
     * @return <code>String</code> value
     */
    public String getValue(String name)
    {
        return (String)entries.get(name);
    }

    /**
     * <code>getNames</code> returns an enumeration with all keys in this
     * object.
     *
     * @returns Enumeration of names, which should have associated values.
     */
    public Enumeration getNames()
    {
	return entries.keys();
    }

    /**
     * <code>getXMLNS</code> is overloaded by derived classes to allow the
     * toString and appendItem() code to be fixed.
     */
    protected abstract String getXMLNS();

    /**
     * <code>appendItem</code> appends the XML representation of the
     * current packet data to the specified <code>StringBuffer</code>.
     *
     * @param retval The <code>StringBuffer</code> to append to
     */
    public void appendItem(StringBuffer retval)
    {
	retval.append("<query xmlns=\"");
	retval.append(getXMLNS());
	retval.append("\">");
        
        Enumeration names=entries.keys();
        if (names!=null)
        {
            while (names.hasMoreElements())
            {
                String name=(String)names.nextElement();
                appendChild(retval,
                              name,
                              (String)entries.get(name));
            }
        }
        retval.append("</query>");
    }
}
