/*
 *   License
 *
 * The contents of this file are subject to the Jabber Open Source License
 * Version 1.0 (the "License").  You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License.  You
 * may obtain a copy of the License at http://www.jabber.com/license/ or at
 * http://www.opensource.org/.  
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 *   Copyrights
 *
 * Portions created by or assigned to Jabber.com, Inc. are 
 * Copyright (c) 2000 Jabber.com, Inc.  All Rights Reserved.  Contact
 * information for Jabber.com, Inc. is available at http://www.jabber.com/.
 *
 * Portions Copyright (c) 1999-2000 David Waite 
 *
 *   Acknowledgements
 * 
 * Special thanks to the Jabber Open Source Contributors for their
 * suggestions and support of Jabber.
 * 
 *   Changes
 *
 */

package org.jabber.jabberbeans.Extension;

import java.util.Hashtable;

/**
 * A <code>HashExtensionBuilder</code> is used to generate an 
 * IQRegisterExtension or an IQSearchRequest, which represent the data 
 * stored in the particular namespace. 
 *
 * NOTE: it is my personal hope that this extension dies a horrible death at
 * a later date, probably at the hand of XML forms.
 *
 * all parameters are subject to interpretation - the names are meant to be 
 * labels to editable text boxes, with instructions being broadcast on how to
 * use the interface.
 *
 * also note that the values do not have default states - <name/> is 
 * represented by name.equals(""), whereas name=null indicates the element
 * is not present
 *
 * @author  David Waite <a href="mailto:dwaite@jabber.com">
 *                      <i>&lt;dwaite@jabber.com&gt;</i></a>
 * @author  $Author: mass $
 * @version $Revision: 1.4 $
 */
public abstract class HashExtensionBuilder
    implements ExtensionBuilder
{
    /** list of name/value pairs */
    private Hashtable entries;

    /** Creates a new <code>HashExtensionBuilder</code> instance.  */
    public HashExtensionBuilder()
    { reset(); }

    /**
     * <code>reset</code> clears all data values (sets to null), so that the
     * builder may be reused.
     */
    public void reset()
    {
        entries=new Hashtable();
    }
    
    /**
     * <code>set</code> changes the value associated with a name, or removes
     * the name key from the hashtable altogether if value==null
     *
     * @param name a <code>String</code> value
     * @param value a <code>String</code> value
     */
    public void set(String name, String value)
    {
        if (value==null)
            entries.remove(name);
        else entries.put(name,value);
    }
    
    /**
     * <code>getTable</code> returns a hashtable of the internal name/value
     * pair representation.
     *
     * @return a <code>Hashtable</code>
     */
    public Hashtable getTable()
    { return entries; }
}
