/*
 *   License
 *
 * The contents of this file are subject to the Jabber Open Source License
 * Version 1.0 (the "License").  You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License.  You
 * may obtain a copy of the License at http://www.jabber.com/license/ or at
 * http://www.opensource.org/.  
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 *   Copyrights
 *
 * Portions created by or assigned to Jabber.com, Inc. are 
 * Copyright (c) 2000 Jabber.com, Inc.  All Rights Reserved.  Contact
 * information for Jabber.com, Inc. is available at http://www.jabber.com/.
 *
 * Portions Copyright (c) 1999-2000 David Waite 
 *
 *   Acknowledgements
 * 
 * Special thanks to the Jabber Open Source Contributors for their
 * suggestions and support of Jabber.
 * 
 *   Changes
 *
 */

package org.jabber.jabberbeans.Extension;

import java.util.Vector;
import java.util.Enumeration;
import org.jabber.jabberbeans.*;

/**
 * <code>IQAgents</code> contains the jabber:iq:agents extension, which is a
 * list of (sub) agents known by the server or directed party.
 *
 * @author  David Waite <a href="mailto:dwaite@jabber.com">
 *                      <i>&lt;dwaite@jabber.com&gt;</i></a>
 * @author  $Author: mass $
 * @version $Revision: 1.9 $
 */
public class IQAgents
    extends XMLData
    implements QueryExtension
{
    /** Vector of 'Agent' objects contained */
    private Vector Agents;

    /**
     * Creates a new <code>IQAgents</code> instance, based on the builder
     * state.
     *
     * @param builder an <code>IQAgentsBuilder</code> value
     * @exception InstantiationException if malformed or insufficient data is
     * in the builder.
     */
    public IQAgents(IQAgentsBuilder builder)
        throws InstantiationException
    {
        Agents=(Vector)builder.getAgents().clone();
    }

    /**
     * returns an enumeration of <code>agents</code> contained within this
     * object.
     *
     * @return an <code>Enumeration</code> value
     */
    public Enumeration agents()
    {
        return Agents.elements();
    }


    /**
     * <code>appendItem</code> converts this packet to XML, either an
     * &lt;agent&gt; block in a jabber:iq:agents extension, or its own
     * jabber:iq:agent extension. It then appends it to a StringBuffer.
     *
     * @param retval The <code>StringBuffer</code> to append to
     */
    public void appendItem(StringBuffer retval)
    {
	retval.append("<query xmlns=\"jabber:iq:agents\"");
        Enumeration items=agents();
        
        if (items==null)
        {
            retval.append("/>");
            return;
        }
        else
            retval.append('>');

        while (items.hasMoreElements())
            ((Agent)items.nextElement()).appendItem(retval);
        
        retval.append("</query>");
    }
}
