/*
 *   License
 *
 * The contents of this file are subject to the Jabber Open Source License
 * Version 1.0 (the "License").  You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License.  You
 * may obtain a copy of the License at http://www.jabber.com/license/ or at
 * http://www.opensource.org/.  
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 *   Copyrights
 *
 * Portions created by or assigned to Jabber.com, Inc. are 
 * Copyright (c) 2000 Jabber.com, Inc.  All Rights Reserved.  Contact
 * information for Jabber.com, Inc. is available at http://www.jabber.com/.
 *
 * Portions Copyright (c) 1999-2000 David Waite 
 *
 *   Acknowledgements
 * 
 * Special thanks to the Jabber Open Source Contributors for their
 * suggestions and support of Jabber.
 * 
 *   Changes
 *
 */

package org.jabber.jabberbeans.Extension;

import java.util.Vector;

/**
 * <code>IQAgentsBuilder</code> is used to construct IQAgents objects
 *
 * @see Agent
 * @see IQAgents
 *
 * @author  David Waite <a href="mailto:dwaite@jabber.com">
 *                      <i>&lt;dwaite@jabber.com&gt;</i></a>
 * @author  $Author: mass $
 * @version $Revision: 1.6 $
 */
public class IQAgentsBuilder
    implements ExtensionBuilder
{
    /** Vector of Agents objects contained. */
    private Vector agentList;

    /** Creates a new <code>IQAgentsBuilder</code> instance. */
    public IQAgentsBuilder()
    { reset(); }
    
    /**
     * <code>reset</code> the builder to a default state, so it can be reused.
     */
    public void reset()
    { agentList=new Vector(); }

    /**
     * <code>addAgent</code> adds a new agent object to the end of this
     * list.
     *
     * @param agent an <code>Agent</code> value
     */
    public void addAgent(Agent agent)
    {
        if (!agentList.contains(agent))
            agentList.addElement(agent);
    }

    /**
     * <code>delAgent</code> removes an agent from this list, if it is present
     *
     * @param agent an <code>Agent</code> value
     */
    public void delAgent(Agent agent)
    {
        if (agentList.contains(agent))
            agentList.removeElement(agent);
    }

    /**
     * <code>getAgents</code> returns the vector representing the agent
     * objects associated with this object.
     *
     * @return a <code>Vector</code> value
     */
    public Vector getAgents()
    { return agentList; }

    /**
     * <code>build</code> a new IQAgents object
     *
     * @return an <code>Extension</code> value
     * @exception InstantiationException if insufficient or incorrect data
     * was proviced.
     */
    public Extension build()
        throws InstantiationException
    { return new IQAgents(this); }
}
