/*
 *   License
 *
 * The contents of this file are subject to the Jabber Open Source License
 * Version 1.0 (the "License").  You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License.  You
 * may obtain a copy of the License at http://www.jabber.com/license/ or at
 * http://www.opensource.org/.  
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 *   Copyrights
 *
 * Portions created by or assigned to Jabber.com, Inc. are 
 * Copyright (c) 2000 Jabber.com, Inc.  All Rights Reserved.  Contact
 * information for Jabber.com, Inc. is available at http://www.jabber.com/.
 *
 * Portions Copyright (c) 1999-2000 David Waite 
 *
 *   Acknowledgements
 * 
 * Special thanks to the Jabber Open Source Contributors for their
 * suggestions and support of Jabber.
 * 
 *   Changes
 *
 */

package org.jabber.jabberbeans.Extension;

/**
 * <code>IQAuthBuilder</code> is the class used for building an
 * IQAuth Extension.
 *
 * @see ExtensionBuilder
 * @see IQAuth
 *
 * @author  David Waite <a href="mailto:dwaite@jabber.com">
 *                      <i>&lt;dwaite@jabber.com&gt;</i></a>
 * @author  $Author: mass $
 * @version $Revision: 1.11 $
 */
public class IQAuthBuilder
    implements ExtensionBuilder
{
    /** current username value */
    private String username;

    /** current resource value */
    private String resource;

    /** current password value */
    private String password;

    /** current SHA1 value */
    private String SHA1Digest;

    private String ZeroKHash;
    
    private String ZeroKToken;
    
    private int sequence;

    /**
     * Creates a new <code>IQAuthBuilder</code> instance.
     */
    public IQAuthBuilder()
    { reset(); }

    /**
     * <code>reset</code> restores the variables to their default state, so
     * that this builder may be reused.
     */
    public void reset()
    { 
	username = resource = password = SHA1Digest = ZeroKHash = 
	    ZeroKToken = null; 
	sequence = -1;
    }

    /**
     * returns the current username
     *
     * @return a <code>String</code> value, or null if none
     */
    public String getUsername()
    { return username; }

    /**
     * sets the current username.
     *
     * @param username a <code>String</code> value, or null to clear
     */
    public void setUsername(String username)
    { this.username=username; }

    /**
     * gets the current resource.
     *
     * @return a <code>String</code> value, or null if blank
     */
    public String getResource()
    { return resource; }

    /**
     * sets the resource.
     *
     * @param res a <code>String</code> value, or null to clear
     */
    public void setResource(String res)
    { this.resource=res; }

    /**
     * gets the password.
     *
     * @return a <code>String</code> value, or null if blank
     */
    public String getPassword()
    { return password; }
    
    /**
     * sets the password.
     *
     * @param password a <code>String</code> value, or null to clear
     */
    public void setPassword(String password)
    { this.password=password; }

    /**
     * get the current value of the SHA1 Digest field.
     *
     * @return a <code>String</code> value, or null if blank
     */
    public String getSHA1Digest()
    { return SHA1Digest; }

    /**
     * set the current value of the SHA1 digest field.
     *
     * @param sha1 a <code>String</code> value, or null to clear
     */
    public void setSHA1Digest(String sha1)
    { this.SHA1Digest=sha1; }

    public String getZeroKHash()
    { return ZeroKHash; }

    public void setZeroKHash(String hash)
    { ZeroKHash = hash; }
    
    public String getZeroKToken()
    { return ZeroKToken; }

    public void setZeroKToken(String token)
    { ZeroKToken = token; }

    public int getZeroKSequence()
    { return sequence; }

    public void setZeroKSequence(int sequence)
    { this.sequence = sequence; }  

    /**
     * <code>build</code> generates a new extension object based on the 
     * information stored in this class.
     *
     * @return an <code>Extension</code> value
     * @exception InstantiationException if insufficient or malformed
     * information was provided
     */
    public Extension build()
        throws InstantiationException
    { return new IQAuth(this); }
}
