/*
 *   License
 *
 * The contents of this file are subject to the Jabber Open Source License
 * Version 1.0 (the "License").  You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License.  You
 * may obtain a copy of the License at http://www.jabber.com/license/ or at
 * http://www.opensource.org/.  
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 *   Copyrights
 *
 * Portions created by or assigned to Jabber.com, Inc. are 
 * Copyright (c) 2000 Jabber.com, Inc.  All Rights Reserved.  Contact
 * information for Jabber.com, Inc. is available at http://www.jabber.com/.
 *
 *   Acknowledgements
 * 
 * Special thanks to the Jabber Open Source Contributors for their
 * suggestions and support of Jabber.
 * 
 *   Changes
 *
 */

package org.jabber.jabberbeans.Extension;

import java.util.Enumeration;
import java.util.Vector;
import org.jabber.jabberbeans.*;

/**
 * A <code>IQAutoUpdate</code> is used to relay additional information about
 * an update available for a piece of software.
 *
 * @author  David Waite <a href="mailto:dwaite@jabber.com">
 *                      <i>&lt;dwaite@jabber.com&gt;</i></a>
 * @author  $Author: mass $
 * @version $Revision: 1.7 $
 */
public class IQAutoUpdate
    extends XMLData
    implements QueryExtension
{
    /**
     * list of UpdateInfo objects associated with this extension. Each
     * UpdateInfo represents a different software version available.
     *
     * @see UpdateInfo
     */ 
    private Vector info;
    
    /**
     * Construct a new IQAutoUpdate object from a vector of UpdateInfo objects
     *
     * @param info <code>Vector</code> of <code>UpdateInfo</codE> objects.
     */
    public IQAutoUpdate(Vector info)
    {
	this.info=(Vector)info.clone();
    }

    /**
     * returns an enumeration of <code>UpdateInfo</code> objects contained
     * within this Extension.
     *
     * @return <code>UpdateInfo Enumeration</code>, with each object 
     * representing a different software version.
     */
    public Enumeration versions()
    {
	return info.elements();
    }

    /**
     * <code>appendItem</code> appends the XML representation of the
     * current packet data to the specified <code>StringBuffer</code>.
     *
     * @param retval The <code>StringBuffer</code> to append to
     */
    public void appendItem(StringBuffer retval)
    {
	retval.append("<query xmlns=\"jabber:iq:autoupdate\">");
	Enumeration e=versions();
	while (e.hasMoreElements())
		   ((UpdateInfo)e.nextElement()).appendItem((retval));
	retval.append("</query>");
    }
}

