/*
 *   License
 *
 * The contents of this file are subject to the Jabber Open Source License
 * Version 1.0 (the "License").  You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License.  You
 * may obtain a copy of the License at http://www.jabber.com/license/ or at
 * http://www.opensource.org/.  
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 *   Copyrights
 *
 * Portions created by or assigned to Jabber.com, Inc. are 
 * Copyright (c) 2000 Jabber.com, Inc.  All Rights Reserved.  Contact
 * information for Jabber.com, Inc. is available at http://www.jabber.com/.
 *
 *   Acknowledgements
 * 
 * Special thanks to the Jabber Open Source Contributors for their
 * suggestions and support of Jabber.
 * 
 *   Changes
 *
 */

package org.jabber.jabberbeans.Extension;

import java.util.Vector;

/**
 * An <code>IQAutoUpdateBuilder</code> is used to generate a 
 * jabber:iq:autoupdate object, a set of UpdateInfo objects which represent
 * different available software versions.
 *
 * @author  David Waite <a href="mailto:dwaite@jabber.com">
 *                      <i>&lt;dwaite@jabber.com&gt;</i></a>
 * @author  $Author: mass $
 * @version $Revision: 1.4 $
 */
public class IQAutoUpdateBuilder
    extends VectorExtensionBuilder
{
    /**
     * Construct an <code>IQAutoUpdateBuilder</code> object, used to create
     * <code>IQAutoUpdate</code> objects
     */
    public IQAutoUpdateBuilder()
    {
	super();
    }

    /**
     * Add an UpdateInfo object to this builder
     *
     * @param entry item to add
     */
    public void addUpdateInfo(UpdateInfo entry)
    {
	vector.addElement(entry);
    }

    /**
     * Delete an UpdateInfo object from this builder
     *
     * @param entry item to remove
     */
    public void delUpdateInfo(UpdateInfo entry)
    {
	if (vector.contains(entry))
	    vector.removeElement(entry);
    }

    /**
     * Build an IQAutoUpdate object based on the current state of the builder.
     *
     * @return the new <code>IQAutoUpdate Extension</code>
     */
    public Extension build()
    {
	return new IQAutoUpdate(vector);
    }
}
