/*
 *   License
 *
 * The contents of this file are subject to the Jabber Open Source License
 * Version 1.0 (the "License").  You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License.  You
 * may obtain a copy of the License at http://www.jabber.com/license/ or at
 * http://www.opensource.org/.  
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 *   Copyrights
 *
 *	 Shawn Wilton
 */

package org.jabber.jabberbeans.Extension;

import java.net.*;
import org.jabber.jabberbeans.*;

/*
 * <code>IQPassBuilder</code> is the class used for building a IQPass extension
 *
 *
 * @see ExtensionBuilder
 * @see IQPass
 *
 *
 * @author  Shawn Wilton <a href="mailto:shawn@black9.net">
 *                      <i>&lt;shawn@black9.net&gt;</i></a>
 * @author  $Author: XB $
 * @version $Revision: 0.0.0.1 $
 */


public class IQPass extends XMLData implements QueryExtension
{	
	//a <code>String</code> for the server info you send to the other party
	private String server_url;
	
	//a <code>int</code> for the port info you send to the other party
	private int server_port;
	
	// a <code>String</code> which represents the client String
	private String client_url;

	// a <code>int</code> which represents the client port
	private int client_port;

	// a <code>String</code> which represents the proxy String
	private String proxy_url;

	// a <code>int</code> which represents the proxy port
	private int proxy_port;

	// a <code>int</code> which represents the expiration period on the connection
	private int expiration;


	/* Creates a new <code>IQPassExtension</code> instance. This will fail if
	 * the builder does not have sufficient or correct information 
	 *
	 * @param builder an <code>IQPassExtensionBuilder</code> which holds the
	 * values we are using.
	 *
	 * @exception InstantiationException thrown if the builder does not hold
	 * sufficient data to create a valid Extension snippet.
	 */
	public IQPass(IQPassBuilder builder) throws InstantiationException
	{
		this.server_url = builder.getServer();
		this.server_port = builder.getServerPort();
		this.client_url = builder.getClient();
		this.client_port = builder.getClientPort();
		this.proxy_url = builder.getProxy();
		this.proxy_port = builder.getProxyPort();
		
		this.expiration = builder.getExpiration();
	}

	/**
	 * <code>getServer</code> returns the value of the server_url attribute
	 *
	 * @return a <code>String</code> value
	 */
	public String getServer()
	{return new String(server_url);}
	
	public int getServerPort()
	{return server_port;}
	
	
	public String getClient()
	{return new String(client_url);}
	
	public int getClientPort()
	{return client_port;}
	
	
	public String getProxy()
	{return new String(proxy_url);}
	
	public int getProxyPort()
	{return proxy_port;}

	
	public int getExpiration()
	{return expiration;}

	
	/**
	 * <code>appendItem</code> appends the XML representation of the
	 * current packet data to the specified <code>StringBuffer</code>.
	 *
	 * @param retval The <code>StringBuffer</code> to append to
	 */
	public void appendItem(StringBuffer retval)
	{
		retval.append("<query xmlns=\"jabber:iq:pass\">");
		
		
		//Now append the server
		if(server_url != null)
		{
			retval.append("<server ");
			appendAttrib(retval, "port", Integer.toString(server_port));
			retval.append(">" + server_url + "</server>");		
		}
		
		//Now append the client
		if(client_url != null)
		{
			retval.append("<client ");
			appendAttrib(retval, "port", Integer.toString(client_port));
			retval.append(">" + client_url + "</client>");		
		}
		
		//Now append the proxy
		if(proxy_url != null)
		{
			retval.append("<proxy ");
			appendAttrib(retval, "port", Integer.toString(proxy_port));
			retval.append(">" + proxy_url + "</proxy>");		
		}

		//The connection expiration limit
		appendChild(retval, "expire", Integer.toString(expiration));
		
		//Append close tag
		retval.append("</query>");
	}
}