/*
 *   License
 *
 * The contents of this file are subject to the Jabber Open Source License
 * Version 1.0 (the "License").  You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License.  You
 * may obtain a copy of the License at http://www.jabber.com/license/ or at
 * http://www.opensource.org/.  
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 *   Copyrights
 *
 *	 Shawn Wilton
 */

package org.jabber.jabberbeans.Extension;

import java.net.*;
/*
 * <code>IQPassBuilder</code> is the class used for building a IQPass extension
 *
 *
 * @see ExtensionBuilder
 * @see IQPass
 *
 *
 * @author  Shawn Wilton <a href="mailto:shawn@black9.net">
 *                      <i>&lt;shawn@black9.net&gt;</i></a>
 * @author  $Author: XB $
 * @version $Revision: 0.0.0.1 $
 */


public class IQPassBuilder implements ExtensionBuilder
{
		//a <code>String</code> for the server info you send to the other party
	private String server_url;
	
	//a <code>int</code> for the port info you send to the other party
	private int server_port;
	
	// a <code>String</code> which represents the client String
	private String client_url;

	// a <code>int</code> which represents the client port
	private int client_port;

	// a <code>String</code> which represents the proxy String
	private String proxy_url;

	// a <code>int</code> which represents the proxy port
	private int proxy_port;

	// a <code>int</code> which represents the expiration period on the connection
	private int expiration;

	
	
	/*
	 * Creates a new <code>IQPassBuilder</code> instance.
	 */
	public IQPassBuilder()
	{reset();}

	
	/*
	 * <code>reset</code> restores the variables to their default state, so
	 * that this builder may be reused.
	 */
	public void reset()
	{
		//Set the expiration to the default
		expiration = 600;
		
		server_url = null;
		server_port = -1;
		
		client_url = null;
		client_port = -1;
		
		proxy_url = null;
		proxy_port = -1;		
	}

	
	/*
	 * returns the expiration
	 *
	 * @return a <code>String</code> value, or null if none
	 */
	public int getExpiration()
	{return expiration;}

	
	/**
	 * sets the expiration
	 *
	 * @param expiration a <code>String</code> value, or null to clear
	 */
	public void setExpiration(int exp)
	{this.expiration = exp;}

	
	/*
	 * gets the server String
	 *
	 * @return a <code>String</code> value, or null if blank
	 */
	public String getServer()
	{return server_url;}

	
	/*
	 * sets the server String
	 *
	 * @param String a <code>String</code> value, or null to clear
	 *
	 */
	public void setServer(String String)
	{this.server_url = String;}
	
	
	/*
	 * gets the server port
	 *
	 * @return a <code>int</code> value, or null if blank
	 */
	public int getServerPort()
	{return server_port;}

	
	/*
	 * sets the server port
	 *
	 * @param port a <code>int</code> value, or null to clear
	 *
	 */
	public void setServerPort(int port)
	{this.server_port = port;}
	
	
	/*
	 * gets the client String
	 *
	 * @return a <code>String</code> value, or null if blank
	 */
	public String getClient()
	{return client_url;}

	
	/*
	 * sets the client String
	 *
	 * @param String a <code>String</code> value, or null to clear
	 *
	 */
	public void setClient(String String)
	{this.client_url = String;}
	
	
	/*
	 * gets the client port
	 *
	 * @return a <code>int</code> value, or null if blank
	 */
	public int getClientPort()
	{return client_port;}

	
	/*
	 * sets the client port
	 *
	 * @param port a <code>int</code> value, or null to clear
	 *
	 */
	public void setClientPort(int port)
	{this.client_port = port;}
	
	
	/*
	 * gets the proxy String
	 *
	 * @return a <code>String</code> value, or null if blank
	 */
	public String getProxy()
	{return proxy_url;}

	
	/*
	 * sets the proxy String
	 *
	 * @param String a <code>String</code> value, or null to clear
	 *
	 */
	public void setProxy(String String)
	{this.proxy_url = String;}
	
	
	/*
	 * gets the proxy port
	 *
	 * @return a <code>int</code> value, or null if blank
	 */
	public int getProxyPort()
	{return proxy_port;}

	
	/*
	 * sets the proxy port
	 *
	 * @param port a <code>int</code> value, or null to clear
	 *
	 */
	public void setProxyPort(int port)
	{this.proxy_port = port;}
	
	
	/*
	 * <code>build</code> generates a new extension object based on the 
	 * information stored in this class.
	 *
	 * @return an <code>Extension</code> value
	 * @exception InstantiationException if insufficient or malformed
	 * information was provided
	 */
	public Extension build() throws InstantiationException
	{return new IQPass(this);}
}
