/*
 *   License
 *
 * The contents of this file are subject to the Jabber Open Source License
 * Version 1.0 (the "License").  You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License.  You
 * may obtain a copy of the License at http://www.jabber.com/license/ or at
 * http://www.opensource.org/.  
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 *   Copyrights
 *
 * Portions created by or assigned to Jabber.com, Inc. are 
 * Copyright (c) 2000 Jabber.com, Inc.  All Rights Reserved.  Contact
 * information for Jabber.com, Inc. is available at http://www.jabber.com/.
 *
 *   Acknowledgements
 * 
 * Special thanks to the Jabber Open Source Contributors for their
 * suggestions and support of Jabber.
 * 
 *   Changes
 *
 */

package org.jabber.jabberbeans.Extension;

import java.io.Serializable;
import org.jabber.jabberbeans.*;

/**
 * An <code>IQPrivate</code> Extension object could be considered rather odd -
 * all it does is hold another, custom extension. The idea is that you can
 * store XML data on the server, and recall it according to XML namespace.
 *
 * A custom Extension holds the data, and will require a registered handler
 * for parsing it back out, same as all other extensions.
 *
 * @author  David Waite <a href="mailto:dwaite@jabber.com">
 *                      <i>&lt;dwaite@jabber.com&gt;</i></a>
 * @author  $Author: mass $
 * @version $Revision: 1.7 $
 */
public class IQPrivate
    extends XMLData
    implements QueryExtension
{
    /**
     * Internal <code>Extension</code> which is to be stored, or is being
     * recalled from the server.
     */
    private Extension data;

    /**
     * Construct a new IQPrivate Extension, based around another custom
     * Extension.
     *
     * @param privateData Extension to be stored or being retrieved from the
     *                    server.
     */
    public IQPrivate(Extension privateData)
    {
	data=privateData;
    }

    /**
     * Fetch the internal Extension from within this IQPrivate object
     *
     * @return internal <code>Extension</code> from this object.
     */
    public Extension getPrivateData()
    {
	return data;
    }

    /**
     * <code>appendItem</code> appends the XML representation of the
     * current packet data to the specified <code>StringBuffer</code>.
     *
     * @param retval The <code>StringBuffer</code> to append to
     */
    public void appendItem(StringBuffer retval)
    {

	retval.append("<query xmlns=\"jabber:iq:private\"");

	if (data==null)
	{
	    retval.append("/>");
	    return;
	}
	else
	    retval.append('>');
	
	//add inner element
	data.appendItem(retval);
	
	retval.append("</query>");
    }
}
