/*
 *   License
 *
 * The contents of this file are subject to the Jabber Open Source License
 * Version 1.0 (the "License").  You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License.  You
 * may obtain a copy of the License at http://www.jabber.com/license/ or at
 * http://www.opensource.org/.  
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 *   Copyrights
 *
 * Portions created by or assigned to Jabber.com, Inc. are 
 * Copyright (c) 2000 Jabber.com, Inc.  All Rights Reserved.  Contact
 * information for Jabber.com, Inc. is available at http://www.jabber.com/.
 *
 *   Acknowledgements
 * 
 * Special thanks to the Jabber Open Source Contributors for their
 * suggestions and support of Jabber.
 * 
 *   Changes
 *
 */

package org.jabber.jabberbeans.Extension;

import java.util.Enumeration;
import java.util.Vector;

/**
 * An <code>IQSearchRequest</code> lets you request the searchable fields for
 * a searchable resource, and also lets you respond back with the items you
 * wish to search for. This code is very similar to jabber:iq:register, and
 * thus shares code with it.
 *
 * @author  David Waite <a href="mailto:dwaite@jabber.com">
 *                      <i>&lt;dwaite@jabber.com&gt;</i></a>
 * @author  $Author: mass $
 * @version $Revision: 1.5 $
 */
public class IQSearchRequest
    extends HashExtension
    implements QueryExtension
{
    /**
     * Construct a new IQSearchRequest based on an IQSearchRequestBuilder
     *
     * @param builder IQSearchRequestBuilder which this object will be based
     */ 
    public IQSearchRequest(IQSearchRequestBuilder builder)
	throws InstantiationException
    {
	super(builder);
    }
	
    /**
     * Used to fetch the internal XMLNS, which is used by AppendItem and
     * toString to return the proper XML representation.
     *
     * @return <code>String</code> holding the XML namespace
     */
    protected String getXMLNS()
    {
	return "jabber:iq:search";
    }
}
