/*
 *   License
 *
 * The contents of this file are subject to the Jabber Open Source License
 * Version 1.0 (the "License").  You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License.  You
 * may obtain a copy of the License at http://www.jabber.com/license/ or at
 * http://www.opensource.org/.  
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 *   Copyrights
 *
 * Portions created by or assigned to Jabber.com, Inc. are 
 * Copyright (c) 2000 Jabber.com, Inc.  All Rights Reserved.  Contact
 * information for Jabber.com, Inc. is available at http://www.jabber.com/.
 *
 *   Acknowledgements
 * 
 * Special thanks to the Jabber Open Source Contributors for their
 * suggestions and support of Jabber.
 * 
 *   Changes
 *
 */

package org.jabber.jabberbeans.Extension;

import java.util.Enumeration;
import java.util.Vector;
import org.jabber.jabberbeans.*;

/**
 * An <code>IQSearchResult</code> holds a vector of SearchResult items,
 * representing individual records resulting from a search.
 * <p>
 *
 * @author  David Waite <a href="mailto:dwaite@jabber.com">
 *                      <i>&lt;dwaite@jabber.com&gt;</i></a>
 * @author  $Author: mass $
 * @version $Revision: 1.8 $
 */
public class IQSearchResult
    extends XMLData
    implements QueryExtension
{
    /** Vector of SearchResult items */
    private Vector searchResults;

    /** Construct a new SearchResult based on a vector of SearchResult items
     *
     * @param items SearchResult Vector
     */
    public IQSearchResult(Vector items)
    {
	searchResults=(Vector)items.clone();
    }
	
    /**
     * Enumerate the SearchResults in this extension
     *
     * @return Enumeration of SearchResult items
     */
    public Enumeration items()
    {
	return searchResults.elements();
    }

    /**
     * <code>appendItem</code> appends the XML representation of the
     * current packet data to the specified <code>StringBuffer</code>.
     *
     * @param retval The <code>StringBuffer</code> to append to
     */
    public void appendItem(StringBuffer retval)
    {
	retval.append("<query xmlns=\"jabber:iq:search\">");

	Enumeration e=items();
	while (e.hasMoreElements())
	    ((SearchResult)e.nextElement()).appendItem(retval);

	retval.append("</query>");
    }
}


