/*
 *   License
 *
 * The contents of this file are subject to the Jabber Open Source License
 * Version 1.0 (the "License").  You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License.  You
 * may obtain a copy of the License at http://www.jabber.com/license/ or at
 * http://www.opensource.org/.  
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 *   Copyrights
 *
 * Portions created by or assigned to Jabber.com, Inc. are 
 * Copyright (c) 2000 Jabber.com, Inc.  All Rights Reserved.  Contact
 * information for Jabber.com, Inc. is available at http://www.jabber.com/.
 *
 *   Acknowledgements
 * 
 * Special thanks to the Jabber Open Source Contributors for their
 * suggestions and support of Jabber.
 * 
 *   Changes
 *
 */

package org.jabber.jabberbeans.Extension;

import java.util.Vector;

/**
 * An <code>IQSearchResultBuilder</code> is used to generate a 
 * jabber:iq:search result, one of the two separate extension objects 
 * implementing this namespace.
 *
 * @author  David Waite <a href="mailto:dwaite@jabber.com">
 *                      <i>&lt;dwaite@jabber.com&gt;</i></a>
 * @author  $Author: mass $
 * @version $Revision: 1.5 $
 */
public class IQSearchResultBuilder
    extends VectorExtensionBuilder
{
    /** Construct an IQSearchResultBuilder object */
    public IQSearchResultBuilder()
    {
	super();
    }

    /** 
     * Add a SearchResult to the internal list
     *
     * @param entry SearchResult to add
     */
    public void addSearchResult(SearchResult entry)
    {
	vector.addElement(entry);
    }

    /**
     * Delete a SearchResult from the internal list
     *
     * @param entry SearchResult to remove
     */ 
    public void delSearchResult(SearchResult entry)
    {
	if (vector.contains(entry))
	    vector.removeElement(entry);
    }

    /**
     * Build an <code>IQSearchResult Extension</code> based on the current
     * builder state
     *
     * @return new Extension object based on current state
     */
    public Extension build()
    {
	return new IQSearchResult(vector);
    }
}
