/*
 *   License
 *
 * The contents of this file are subject to the Jabber Open Source License
 * Version 1.0 (the "License").  You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License.  You
 * may obtain a copy of the License at http://www.jabber.com/license/ or at
 * http://www.opensource.org/.  
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 *   Copyrights
 *
 * Portions created by or assigned to Jabber.com, Inc. are 
 * Copyright (c) 2000 Jabber.com, Inc.  All Rights Reserved.  Contact
 * information for Jabber.com, Inc. is available at http://www.jabber.com/.
 *
 *   Acknowledgements
 * 
 * Special thanks to the Jabber Open Source Contributors for their
 * suggestions and support of Jabber.
 * 
 *   Changes
 *
 */

package org.jabber.jabberbeans.Extension;

import java.io.Serializable;
import org.jabber.jabberbeans.*;

/**
 * An <code>IQTime</code> Extension object is used to query for the time of a
 * remote client. Provided is the time information in GMT, the timezone of
 * the responding party, and a textual display for the time data. 
 *
 * Any data parsing or handling code is located outside this class.
 *
 * @author  David Waite <a href="mailto:dwaite@jabber.com">
 *                      <i>&lt;dwaite@jabber.com&gt;</i></a>
 * @author  $Author: mass $
 * @version $Revision: 1.7 $
 */
public class IQTime
    extends XMLData
    implements QueryExtension
{
    /** The time in GMT/UTC, in the ISO format (YYYYMMDDTHH:MM:SS*/
    private String time;

    /** The zone which the remote party is located */
    private String zone;

    /** A textual description of the time which the client is located */
    private String display;

    /** Construct a new <code>IQTime</code> object, based on the builder
     * state.
     *
     * @param builder IQTimeBuilder which holds the state this object
     *                will be based on
     */
    public IQTime(IQTimeBuilder builder)
    {
	time=builder.getTime();
	zone=builder.getZone();
	display=builder.getDisplay();
    }

    /** return the time in GMT/UTC, in ISO format (yyyymmddThh:mm:ss) */
    public String getTime()
    {
	return time;
    }

    /** return the time zone which the party is located, if any */
    public String getZone()
    {
	return zone;
    }

    /** return a textual string for displaying the current time */
    public String getDisplay()
    {
	return display;
    }

    /**
     * <code>appendItem</code> converts this packet to XML, either an
     * &lt;agent&gt; block in a jabber:iq:agents extension, or its own
     * jabber:iq:agent extension. It then appends it to a StringBuffer.
     *
     * @param retval The <code>StringBuffer</code> to append to
     */
    public void appendItem(StringBuffer retval)
    {
	retval.append("<query xmlns=\"jabber:iq:time\">");
	
	appendChild(retval,"utc",time);
	appendChild(retval,"tz",zone);
	appendChild(retval,"display",display);
	
	retval.append("</query>");
    }
}
