/*
 *   License
 *
 * The contents of this file are subject to the Jabber Open Source License
 * Version 1.0 (the "License").  You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License.  You
 * may obtain a copy of the License at http://www.jabber.com/license/ or at
 * http://www.opensource.org/.  
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 *   Copyrights
 *
 * Portions created by or assigned to Jabber.com, Inc. are 
 * Copyright (c) 2000 Jabber.com, Inc.  All Rights Reserved.  Contact
 * information for Jabber.com, Inc. is available at http://www.jabber.com/.
 *
 *   Acknowledgements
 * 
 * Special thanks to the Jabber Open Source Contributors for their
 * suggestions and support of Jabber.
 * 
 *   Changes
 *
 */

package org.jabber.jabberbeans.Extension;

import java.util.Hashtable;

/**
 * An <code>IQTimeBuilder</code> is used to generate a jabber:iq:time namespace
 * object.
 *
 * @author  David Waite <a href="mailto:dwaite@jabber.com">
 *                      <i>&lt;dwaite@jabber.com&gt;</i></a>
 * @author  $Author: mass $
 * @version $Revision: 1.4 $
 */
public class IQTimeBuilder
    implements ExtensionBuilder
{
    /** The time in GMT/UTC, in the ISO format (YYYYMMDDTHH:MM:SS*/
    private String time;

    /** The zone which the remote party is located */
    private String zone;

    /** A textual description of the time which the client is located */
    private String display;

    /** Construct a new <code>IQTimeBuilder</code> object */
    public IQTimeBuilder()
    {
	reset();
    }
    
    /** reset this builder to a default state, for reuse */
    public void reset()
    {
	time=null;
	zone=null;
	display=null;
    }

    /** 
     * get the time in GMT/UTC, in ISO format 
     *
     * @return String holding time
     */
    public String getTime()
    {
	return time;
    }

    /** set the time 
     *
     * @param value Time in GMT/UTC, in ISO format
     */
    public void setTime(String value)
    {
	time=value;
    }

    /**
     * get the time zone
     *
     * @return <code>String</code> holding time zone
     */
    public String getZone()
    {
	return zone;
    }

    /**
     * set the time zone
     *
     * @param value <code>String</code> holding time zone
     */
    public void setZone(String value)
    {
	zone=value;
    }

    /**
     * get the textual display string
     *
     * @return <code>String</code> holding textual representation of the time
     */
    public String getDisplay()
    {
	return display;
    }

    /**
     * set the textual display string
     *
     * @param value <code>String</code> holding textual representation of
     *              the time
     */
    public void setDisplay(String value)
    {
	display=value;
    }

    /**
     * Build an <code>IQTime Extension</code> based on the current builder
     * state.
     *
     * @return <code>IQTime Extension</code> based on the current builder
     * state.
     */
    public Extension build()
    {
	return new IQTime(this);
    }
}

