/*
 *   License
 *
 * The contents of this file are subject to the Jabber Open Source License
 * Version 1.0 (the "License").  You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License.  You
 * may obtain a copy of the License at http://www.jabber.com/license/ or at
 * http://www.opensource.org/.  
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 *   Copyrights
 *
 * Portions created by or assigned to Jabber.com, Inc. are 
 * Copyright (c) 2000 Jabber.com, Inc.  All Rights Reserved.  Contact
 * information for Jabber.com, Inc. is available at http://www.jabber.com/.
 *
 *   Acknowledgements
 * 
 * Special thanks to the Jabber Open Source Contributors for their
 * suggestions and support of Jabber.
 * 
 *   Changes
 *
 */

package org.jabber.jabberbeans.Extension;

import java.io.Serializable;
import org.jabber.jabberbeans.*;

/**
 * An <code>IQVersion</code> Extension object is used to query for the
 * version of a remote client. Provided is the name and version of the used
 * software, as well as the OS which the software is executing.
 *
 * @author  David Waite <a href="mailto:dwaite@jabber.com">
 *                      <i>&lt;dwaite@jabber.com&gt;</i></a>
 * @author  $Author: mass $
 * @version $Revision: 1.7 $
 */
public class IQVersion
    extends XMLData
    implements QueryExtension
{
    /** The name of the client software */
    private String name;

    /** The version of the client software */
    private String version;

    /** A report of the OS on which the software is running */
    private String OS;

    /**
     * build an IQVersion object based on an IQVersionBuilder object
     * 
     * @param builder IQVersionBuilder from which this object will be based
     */
    public IQVersion(IQVersionBuilder builder)
    {
	name=builder.getName();
	version=builder.getVersion();
	OS=builder.getOS();
    }

    /**
     * get the name of the client software.
     *
     * @return <code>String</code> holding the name of the client software
     */ 
    public String getName()
    {
	return name;
    }

    /**
     * get a version string for the client software.
     * 
     * @return <code>String</code> holding a representation of the client
     *         software version
     */
    public String getVersion()
    {
	return version;
    }

    /**
     * get the OS string for the client software.
     *
     * @return <code>String</code> holding the OS value for the client
     *         software
     */
    public String getOS()
    {
	return OS;
    }

    /**
     * <code>appendItem</code> converts this packet to XML, either an
     * &lt;agent&gt; block in a jabber:iq:agents extension, or its own
     * jabber:iq:agent extension. It then appends it to a StringBuffer.
     *
     * @param retval The <code>StringBuffer</code> to append to
     */
    public void appendItem(StringBuffer retval)
    {
	retval.append("<query xmlns=\"jabber:iq:version\">");
	
	appendChild(retval,"name",name);
	appendChild(retval,"version",version);
	appendChild(retval,"os",OS);
	
	retval.append("</query>");
    }
}
