/*
 *   License
 *
 * The contents of this file are subject to the Jabber Open Source License
 * Version 1.0 (the "License").  You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License.  You
 * may obtain a copy of the License at http://www.jabber.com/license/ or at
 * http://www.opensource.org/.  
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 *   Copyrights
 *
 * Portions created by or assigned to Jabber.com, Inc. are 
 * Copyright (c) 2000 Jabber.com, Inc.  All Rights Reserved.  Contact
 * information for Jabber.com, Inc. is available at http://www.jabber.com/.
 *
 *   Acknowledgements
 * 
 * Special thanks to the Jabber Open Source Contributors for their
 * suggestions and support of Jabber.
 * 
 *   Changes
 *
 */

package org.jabber.jabberbeans.Extension;

import java.util.Hashtable;

/**
 * An <code>IQVersionBuilder</code> is used to generate a jabber:iq:version
 * namespace object.
 *
 * @author  David Waite <a href="mailto:dwaite@jabber.com">
 *                      <i>&lt;dwaite@jabber.com&gt;</i></a>
 * @author  $Author: mass $
 * @version $Revision: 1.4 $
 */
public class IQVersionBuilder
    implements ExtensionBuilder
{
    /** The name of the client software */
    private String name;

    /** The version of the client software */
    private String version;

    /** A report of the OS on which the software is running */
    private String OS;

    /** Construct a new IQVersionBuilder object */
    public IQVersionBuilder()
    {
	reset();
    }

    /** reset this object to a default state, for reuse */
    public void reset()
    {
	name=null;
	version=null;
	OS=null;
    }

    /**
     * get the name of the client software
     *
     * @return <code>String</code> holding name of the client software.
     */ 
    public String getName()
    {
	return name;
    }

    /**
     * Set the name of the client software
     *
     * @param value <code>String</code> holding name of the client software
     */
    public void setName(String value)
    {
	name=value;
    }

    /**
     * get the version of the client software
     *
     * @return <code>String</code> holding a representation of the version
     *         of the client software.
     */
    public String getVersion()
    {
	return version;
    }

    /**
     * set the version of the client software
     *
     * @param value <code>String</code> holding a representation of the
     *              version of the client software.
     */
    public void setVersion(String value)
    {
	version=value;
    }

    /**
     * get the OS string for the client software
     *
     * @return <code>String</code> holding the OS of the client
     */
    public String getOS()
    {
	return OS;
    }

    /**
     * set the OS string for the client software
     *
     * @param value <code>String</code> holding the OS of the client
     */
    public void setOS(String value)
    {
	OS=value;
    }
    
    /**
     * Build a <code>IQVersion Extension</code> based on the current builder
     * state.
     *
     * @return <code>IQVersion Extension</code>
     */
    public Extension build()
    {
	return new IQVersion(this);
    }
}
