/*
 *   License
 *
 * The contents of this file are subject to the Jabber Open Source License
 * Version 1.0 (the "License").  You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License.  You
 * may obtain a copy of the License at http://www.jabber.com/license/ or at
 * http://www.opensource.org/.  
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 *   Copyrights
 *
 * Portions created by or assigned to Jabber.com, Inc. are 
 * Copyright (c) 2000 Jabber.com, Inc.  All Rights Reserved.  Contact
 * information for Jabber.com, Inc. is available at http://www.jabber.com/.
 *
 *   Acknowledgements
 * 
 * Special thanks to the Jabber Open Source Contributors for their
 * suggestions and support of Jabber.
 * 
 *   Changes
 *
 */

package org.jabber.jabberbeans.Extension;

import java.util.Hashtable;

/**
 * A <code>OOBBuilder</code> is used to generate an OOB packet (either 
 * jabber:x:oob or jabber:iq:oob)
 *
 * @author  David Waite <a href="mailto:dwaite@jabber.com">
 *                      <i>&lt;dwaite@jabber.com&gt;</i></a>
 * @author  $Author: mass $
 * @version $Revision: 1.4 $
 */
public class OOBBuilder
    implements ExtensionBuilder
{
    /**
     * This boolean is set true for jabber:iq:oob, left false for 
     * jabber:x:oob
     */
    private boolean IQ;

    /** String holding the URL of the out-of-band data. */
    private String URL;

    /** String holding and description of the data being referenced. */
    private String description;

    /** construct a new <code>OOBBuilder</code> object. */
    public OOBBuilder()
    {
	reset();
    }

    /** reset to a default state, so the object can be reused */
    public void reset()
    {
	IQ=true;
	URL=null;
	description=null;
    }
    
    /**
     * return whether this is a jabber:iq:oob or a jabber:x:oob extension
     *
     * @return <code>True</code> for a jabber:iq:oob extension,
     *         <code>False</code> for a jabber:x:oob extension
     */
    public boolean isIQ()
    {
	return IQ;
    }

    /**
     * set whether this is a jabber:iq:oob or a jabber:x:oob extension
     *
     * @param value <code>True</code> for a jabber:iq:oob extension,
     *              <code>False</code> for a jabber:x:oob extension
     */
    public void setIQ(boolean value)
    {
	IQ=value;
    }

    /**
     * get the URL which this OOB is pointing to
     * 
     * @return <code>String</code> holding the URL
     */
    public String getURL()
    {
	return URL;
    }

    /**
     * set the URL which this OOB is pointing to
     *
     * @param value <code>String</code> holding the URL
     */
    public void setURL(String value)
    {
	URL=value;
    }  

    /**
     * get a description of what this OOB represents
     *
     * @return <code>String</code> holding a description of the URL.
     */
    public String getDescription()
    {
	return description;
    }

    /**
     * set a description of what this OOB represents
     *
     * @param value <code>String</code> holding a description of the URL.
     */
    public void setDescription(String value)
    {
	description=value;
    }

    /**
     * build an <code>OOB Extension</code> based on the current builder
     * state.
     *
     * @return new <code>OOB Extension</code>
     */
    public Extension build()
    {
	return new OOB(this);
    }
}

