/*
 *   License
 *
 * The contents of this file are subject to the Jabber Open Source License
 * Version 1.0 (the "License").  You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License.  You
 * may obtain a copy of the License at http://www.jabber.com/license/ or at
 * http://www.opensource.org/.  
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 *   Copyrights
 *
 * Portions created by or assigned to Jabber.com, Inc. are 
 * Copyright (c) 2000 Jabber.com, Inc.  All Rights Reserved.  Contact
 * information for Jabber.com, Inc. is available at http://www.jabber.com/.
 *
 * Portions Copyright (c) 1999-2000 David Waite 
 *
 *   Acknowledgements
 * 
 * Special thanks to the Jabber Open Source Contributors for their
 * suggestions and support of Jabber.
 * 
 *   Changes
 *
 */

package org.jabber.jabberbeans.Extension;

import org.jabber.jabberbeans.RosterItem;
import java.util.Vector;

/**
 * <code>RosterBuilder</code> is the class responsible for building
 * complex roster item lists,
 *
 * @author  David Waite <a href="mailto:dwaite@jabber.com">
 *                      <i>&lt;dwaite@jabber.com&gt;</i></a>
 * @author  $Author: mass $
 * @version $Revision: 1.9 $
 *
 * @see Roster
 */
public class RosterBuilder
    implements ExtensionBuilder
{
    /** List of users */
    private Vector rosterItems=null;

    /** true if an iq:roster, false for x:roster. */
    private boolean IsIQRoster;

    /** Creates a new <code>RosterBuilder</code> instance. */
    public RosterBuilder()
    { reset(); }
    
    /**
     * <code>reset</code> resets the values in rosterItems so that the class
     * may be reused.
     */
    public void reset()
    {
        rosterItems=new Vector();
        IsIQRoster=true;
    }

    /**
     * <code>addRosterItem</code> adds a new RosterItem to the rosterlist.
     *
     * @param e a <code>RosterItem</code> value
     */
    public void addRosterItem(RosterItem e)
    {
        if (!rosterItems.contains(e))
            rosterItems.addElement(e);
    }

    /**
     * <code>delRosterItem</code> deletes a RosterItem from the rosterlist.
     *
     * @param e a <code>RosterItem</code> value
     */
    public void delRosterItem(RosterItem e)
    {
        rosterItems.removeElement(e);
    }

    /**
     * <code>getRosterItems</code> returns the vector of roster items.
     *
     * @return a <code>Vector</code> value
     */
    public Vector getRosterItems()
    {
        return rosterItems;
    }

    /**
     * <code>isIQRoster</code> returns true if this is a jabber:iq:roster
     * namespace object, false if is a jabber:x:roster namespace object.
     *
     * @return a <code>boolean</code> value
     */
    public boolean isIQRoster()
    {
        return IsIQRoster;
    }

    /**
     * <code>setIQRoster</code> changes whether this is a jabber:iq:roster 
     * (true) or a jabber:x:roster (false)
     *
     * @param iqRoster a <code>boolean</code> value
     */
    public void setIQRoster(boolean iqRoster)
    { IsIQRoster=iqRoster; }

    /**
     * <code>build</code> builds a Roster object
     *
     * @return an <code>Extension</code> value
     */
    public Extension build()
        throws InstantiationException
    { return new Roster(this); }
}
