/*
 *   License
 *
 * The contents of this file are subject to the Jabber Open Source License
 * Version 1.0 (the "License").  You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License.  You
 * may obtain a copy of the License at http://www.jabber.com/license/ or at
 * http://www.opensource.org/.  
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 *   Copyrights
 *
 * Portions created by or assigned to Jabber.com, Inc. are 
 * Copyright (c) 2000 Jabber.com, Inc.  All Rights Reserved.  Contact
 * information for Jabber.com, Inc. is available at http://www.jabber.com/.
 *
 *   Acknowledgements
 * 
 * Special thanks to the Jabber Open Source Contributors for their
 * suggestions and support of Jabber.
 * 
 *   Changes
 *
 */

package org.jabber.jabberbeans.Extension;

import java.util.Hashtable;

/**
 * A <code>SearchResultBuilder</code> is used to generate a SearchResult,
 * which is one entry of possibly many in a returned IQSearchResult.
 * 
 * The data stored will be a list of keys with associated values, for
 * instance:
 * <ul>
 *  <li>first=Dave</li>
 *  <li>last=Waite</li>
 *  <li>nick=dwaite</li>
 * </ul> ...and so on.
 *
 * Note that a much better way of doing this would be to keep the search
 * result parameters constant across all the results, since the keys
 * are constant. At that point, there would be one SearchResultKey which
 * would look like this class and could be possibly based on the 
 * IQSearchRequest response, or assume that the server properly returns
 * empty entries for values which come in that aren't assigned by the
 * user, rather than omitting them. Then, the list of items becomes an
 * array.
 *
 * Consider implementing this to be a task for the reader ;-) For now,
 * a basic (poorly optimized) solution will do.
 *
 * @author  David Waite <a href="mailto:dwaite@jabber.com">
 *                      <i>&lt;dwaite@jabber.com&gt;</i></a>
 * @author  $Author: mass $
 * @version $Revision: 1.5 $
 */
public class SearchResultBuilder
    extends HashExtensionBuilder
{
    
    /**
     * Creates a new <code>SearchResultBuilder</code> instance.
     */
    public SearchResultBuilder()
    {
	super();
    }

    /**
     * <code>build</code> a new <code>SearchResult</code>, based on the
     * current builder state
     *
     * @return an <code>Extension</code> value holding a
     *         <code>SearchResult</code>
     * @exception InstantiationException if there is insufficient data
     *            to return a valid object.
     */
    public Extension build()
	throws InstantiationException
    {
	return new SearchResult(this);
    }
}
