/*
 *   License
 *
 * The contents of this file are subject to the Jabber Open Source License
 * Version 1.0 (the "License").  You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License.  You
 * may obtain a copy of the License at http://www.jabber.com/license/ or at
 * http://www.opensource.org/.  
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 *   Copyrights
 *
 * Portions created by or assigned to Jabber.com, Inc. are 
 * Copyright (c) 2000 Jabber.com, Inc.  All Rights Reserved.  Contact
 * information for Jabber.com, Inc. is available at http://www.jabber.com/.
 *
 *   Acknowledgements
 * 
 * Special thanks to the Jabber Open Source Contributors for their
 * suggestions and support of Jabber.
 * 
 *   Changes
 *
 */

package org.jabber.jabberbeans.Extension;

/**
 * An <code>UpdateInfoBuilder</code> is used to construct UpdateInfo objects
 *
 * @author  David Waite <a href="mailto:dwaite@jabber.com">
 *                      <i>&lt;dwaite@jabber.com&gt;</i></a>
 * @author  $Author: mass $
 * @version $Revision: 1.5 $
 */
public class UpdateInfoBuilder
{
    /** 
     * <code>type</code> is the type of update, be it a "release", a "beta", 
     * or a "dev" release.
     */
    private String type; 

    /**
     * <code>version</code> is the version of the software being reported,
     * hopefully the most recent release available.
     */
    private String version;
    
    /**
     * <code>URL</code> holds the unique resource locator value for the
     * client (or user) to get a software update.
     */
    private String URL;
    
    /**
     * <code>priority</code> indicates how severe the priority of the release
     * has been ranked. Options are "optional" or "mandatory"
     */
    private String priority;

    
    /**
     * Creates a new <code>UpdateInfoBuilder</code> instance.
     */
    public UpdateInfoBuilder()
    {
	reset();
    }
    
    /**
     * resets the state of the builder, for reuse
     */
    public void reset()
    {
	type=
	version=
	URL= null;
    }

    /**
     * gets the type of update (be it 'beta', 'release', or 'dev')
     *
     * @return a <code>String</code> value holding the type
     */
    public String getType()
    {
	return type;
    }

    /**
     * sets the type of update (be it 'beta', 'release', or 'dev')
     *
     * @param type a <code>String</code> value holding the type
     */
    public void setType(String type)
    {
	this.type=type;
    }

    /**
     * gets the version string associated with the update
     *
     * @return a <code>String</code> holding the version of the update
     */
    public String getVersion()
    {
	return version;
    }

    /**
     * sets the version string associated with the update
     *
     * @param version a <code>String</code> holding the version of the update
     */
    public void setVersion(String version)
    {
	this.version=version;
    }

    /**
     * gets the URL where the software is located
     *
     * @return a <code>String</code> holding the URL
     */
    public String getURL()
    {
	return URL;
    }

    /**
     * sets the URL where the software is located
     *
     * @param URL a <code>String</code> holding the URL
     */
    public void setURL(String URL)
    {
	this.URL=URL;
    }
    
    /**
     * gets the priority of the update (optional , mandatory)
     *
     * @return a <code>String</code> holding the update priority
     */
   public String getPriority()
    {
	return priority;
    }
    
    /**
     * sets the priority of the update (optional , mandatory)
     *
     * @param priority a <code>String</code> holding the update priority
     */
    public void setPriority(String priority)
    {
	this.priority=priority;
    }

    /**
     * build an <code>UpdateInfo</code> based on the current builder state
     *
     * @return <code>UpdateInfo</code> object
     */
    public UpdateInfo build()
    {
	return new UpdateInfo(this);
    }
}
