/*
 *   License
 *
 * The contents of this file are subject to the Jabber Open Source License
 * Version 1.0 (the "License").  You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License.  You
 * may obtain a copy of the License at http://www.jabber.com/license/ or at
 * http://www.opensource.org/.  
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 *   Copyrights
 *
 * Portions created by or assigned to Jabber.com, Inc. are 
 * Copyright (c) 2000 Jabber.com, Inc.  All Rights Reserved.  Contact
 * information for Jabber.com, Inc. is available at http://www.jabber.com/.
 *
 *   Acknowledgements
 * 
 * Special thanks to the Jabber Open Source Contributors for their
 * suggestions and support of Jabber.
 * 
 *   Changes
 *
 */

package org.jabber.jabberbeans.Extension;

import org.jabber.jabberbeans.*;

/**
 * A <code>XAutoUpdate</code> is used to indicate to a client that there is
 * a new version of some software. Passed is an address to be used to fetch
 * more information via jabber:iq:autoupdate.
 *
 * @author  David Waite <a href="mailto:dwaite@jabber.com">
 *                      <i>&lt;dwaite@jabber.com&gt;</i></a>
 * @author  $Author: mass $
 * @version $Revision: 1.8 $
 */
public class XAutoUpdate extends XMLData implements MessageExtension
{
	/* <code>String</code> holding the JID of the update */
	private String address;


	/* Construct an XAutoUpdate object, based on a <code>String</code of 
	 * a JID
	 *
	 * @param addr <code>String</code> holding the JID where additional
	 *             update information can be found
	 */
	public XAutoUpdate(String addr)
	{address = addr;}


	/*
	 * get the address for additional information on an update
	 * @return <code>String</code> holding the JID where additional
	 *             update information can be found
	 */
	public String getAddress()
	{return address;}


	/*
	 * <code>appendItem</code> appends the XML representation of the
	 * current packet data to the specified <code>StringBuffer</code>.
	 *
	 * @param retval The <code>StringBuffer</code> to append to
	 */
	public void appendItem(StringBuffer retval)
	{
		retval.append("<x xmlns=\"jabber:x:autoupdate\"");

		if (address==null)
		{
			retval.append("/>");
			return;
		}
		retval.append('>');
		escapeString(retval,address);
		retval.append("</x>");
	}
}