/*
 *   License
 *
 * The contents of this file are subject to the Jabber Open Source License
 * Version 1.0 (the "License").  You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License.  You
 * may obtain a copy of the License at http://www.jabber.com/license/ or at
 * http://www.opensource.org/.  
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 *
 */

package org.jabber.jabberbeans.Extension;

import org.jabber.jabberbeans.util.JID;
import org.jabber.jabberbeans.*;


/*
 * An <code>XConference</code> extension handles jabber:x:conference packets. 
 *
 */
public class XConference extends XMLData implements PresenceExtension, MessageExtension
{
	/** address is the party causing the delay */
	private JID address;


	/* 
	 * Construct a new XConference Extension, based on the current state of a
	 * builder object
	 *
	 * @param builder builder object on which the constructed XConference will
	 *                be based
	 */
	public XConference(XConferenceBuilder builder)
	{address = builder.getAddress();}


	/*
	 * get the address of the sending party
	 *
	 * @return <code>JID</code> of the party which sent the message.
	 */
	public JID getAddress()
	{return address;}


	/*
	 * <code>appendItem</code> appends the XML representation of the
	 * current packet data to the specified <code>StringBuffer</code>.
	 *
	 * @param retval The <code>StringBuffer</code> to append to
	 */
	public void appendItem(StringBuffer retval)
	{
		retval.append("<x xmlns=\"jabber:x:conference\"");
		appendAttrib(retval,"jid",address);
		retval.append("/>");
	}
}
