/*
 *   License
 *
 * The contents of this file are subject to the Jabber Open Source License
 * Version 1.0 (the "License").  You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License.  You
 * may obtain a copy of the License at http://www.jabber.com/license/ or at
 * http://www.opensource.org/.  
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 */

package org.jabber.jabberbeans.Extension;

import org.jabber.jabberbeans.util.JID;

/*
 * A <code>XConference</code> extension handles jabber:x:conference packets.
 *
 */
public class XConferenceBuilder implements ExtensionBuilder
{
	/* address of the conference room */
	private JID address;

	/* construct a new XConferenceBuilder object */
	public XConferenceBuilder()
	{reset();}

	/** reset the builder to a default state, for reuse */
	public void reset()
	{address = null;}
	
	
	/*
	 * get the address of the sending party
	 *
	 * @return <code>JID</code> of the party which sent the message.
	 */
	public JID getAddress()
	{return address;}
	
	
	/*
	 * set the address of the sending party
	 *
	 * @param from <code>JID</code> of the party which sent the message.
	 */
	public void setAddress(JID jid)
	{address = jid;}
	
	
	/**
	 * build a new <code>XConference Extension</code> based on the current
	 * builder state
	 *
	 * @return <code>XConference Extension</code>
	 * @throws InstantiationException if there is not sufficient information
	 *         to construct a full XConference object.
	 */
	public Extension build() throws InstantiationException
	{return new XConference(this);}
}