/*
 *   License
 *
 * The contents of this file are subject to the Jabber Open Source License
 * Version 1.0 (the "License").  You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License.  You
 * may obtain a copy of the License at http://www.jabber.com/license/ or at
 * http://www.opensource.org/.  
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 *   Copyrights
 *
 * Portions created by or assigned to Jabber.com, Inc. are 
 * Copyright (c) 2000 Jabber.com, Inc.  All Rights Reserved.  Contact
 * information for Jabber.com, Inc. is available at http://www.jabber.com/.
 *
 * Portions Copyright (c) 1999-2000 David Waite 
 *
 *   Acknowledgements
 * 
 * Special thanks to the Jabber Open Source Contributors for their
 * suggestions and support of Jabber.
 * 
 *   Changes
 *
 */

package org.jabber.jabberbeans;

import org.jabber.jabberbeans.Extension.*;
import java.io.Serializable;

/**
 * <code>InfoQueryBuilder</code> is the class that expands upon PacketBuilder
 * to allow building of InfoQuery objects (packets). The builder is a required
 * object in the creation of said packet, as the number of fields is too 
 * numerous to make direct creation feasable and non-error prone.
 *
 * @author  David Waite <a href="mailto:dwaite@jabber.com">
 *                      <i>&lt;dwaite@jabber.com&gt;</i></a>
 * @author  $Author: mass $
 * @version $Revision: 1.9 $
 */
public class InfoQueryBuilder
    extends PacketBuilder
    implements Serializable
{
    /** Creates a new <code>InfoQueryBuilder</code> instance. */
    public InfoQueryBuilder()
    { reset(); }

    /**
     * <code>reset</code> all parameters (including those in the parent class)
     * to default values
     */
    public void reset()
    { resetBase(); }

    /**
     * <code>build</code> returns a packet, specifically an InfoQuery packet.
     * It will fail if the parameters specified in the builder were not
     * sufficient to create a valid packet.
     *
     * @return a valid <code>Packet</code>
     * @exception InstantiationException if there was not sufficient 
     * information to create a valid InfoQuery packet
     */
    public Packet build()
        throws InstantiationException
    { return new InfoQuery(this); }
}
