/*
 *   License
 *
 * The contents of this file are subject to the Jabber Open Source License
 * Version 1.0 (the "License").  You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License.  You
 * may obtain a copy of the License at http://www.jabber.com/license/ or at
 * http://www.opensource.org/.  
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 *   Copyrights
 *
 * Portions created by or assigned to Jabber.com, Inc. are 
 * Copyright (c) 2000 Jabber.com, Inc.  All Rights Reserved.  Contact
 * information for Jabber.com, Inc. is available at http://www.jabber.com/.
 *
 * Portions Copyright (c) 1999-2000 David Waite 
 *
 *   Acknowledgements
 * 
 * Special thanks to the Jabber Open Source Contributors for their
 * suggestions and support of Jabber.
 * 
 *   Changes
 *
 */

package org.jabber.jabberbeans;

import java.io.Serializable;

/**
 * PacketAdapter is a convenience class - it provides do-nothing 
 * implementations of the PacketListener class, so that clients will work
 * with an upgraded jabberbeans with new packet events.
 *
 * @author  David Waite <a href="mailto:dwaite@jabber.com">
 *                      <i>&lt;dwaite@jabber.com&gt;</i></a>
 * @author  $Author: dwaite $
 * @version $Revision: 1.11 $
 */
public class PacketAdapter
    implements PacketListener,
               Serializable
{
    /**
     * called when a packet is received and has been processed into a packet. 
     * This is just a do-nothing implementation
     *
     * @param p PacketEvent that has just been received.
     */
    public void receivedPacket(PacketEvent p)
    {
	receivedPacket(p.getPacket());
    }

    /**
     * called immediately after any packet is successfully sent. This is 
     * implemented here as a default do-nothing function.
     *
     * @param p PacketEvent that has just been sent
     */
    public void sentPacket(PacketEvent p)
    {
	sentPacket(p.getPacket());
    }


    /**
     * called if a packet is not successfully sent (for instance, if the connection
     * dies while the packet is queued, or a packet is sent while disconnected).
     *
     * @param pe PacketEvent for the failed send
     */
    public void sendFailed(PacketEvent pe)
    {}

    /**
     * @deprecated use {@link #receivedPacket(PacketEvent)} instead, will
     * be removed before 1.0
     */
    public void receivedPacket(Packet p)
    {}

    /**
     * @deprecated use {@link #sentPacket(PacketEvent)} instead, will be
     * removed before 1.0
     */
    public void sentPacket(Packet p)
    {}
}
