/*
 *   License
 *
 * The contents of this file are subject to the Jabber Open Source License
 * Version 1.0 (the "License").  You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License.  You
 * may obtain a copy of the License at http://www.jabber.com/license/ or at
 * http://www.opensource.org/.  
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 *   Copyrights
 *
 * Portions created by or assigned to Jabber.com, Inc. are 
 * Copyright (c) 2000 Jabber.com, Inc.  All Rights Reserved.  Contact
 * information for Jabber.com, Inc. is available at http://www.jabber.com/.
 *
 *   Acknowledgements
 * 
 * Special thanks to the Jabber Open Source Contributors for their
 * suggestions and support of Jabber.
 * 
 *   Changes
 *
 */

package org.jabber.jabberbeans;

import java.io.Serializable;
import java.util.EventObject;

/**
 * A <code>PacketEvent</code> is an event occuring on a connection (from
 * the ConnectionBean) describing an event occuring from a unit of data being 
 * sent or received.
 * 
 * @author  David Waite <a href="mailto:dwaite@jabber.com">
 *                      <i>&lt;dwaite@jabber.com&gt;</i></a>
 * @author  $Author: mass $
 * @version $Revision: 1.5 $
 */
public class PacketEvent
    extends EventObject
{
    /** packet which this event is about */
    private Packet packet=null;

    /** 
     * construct an event with no packet.
     *
     * @param source Source object which is broadcasting the event.
     */
    public PacketEvent(Object source)
    {
	super(source);
    }

    /** 
     * construct an event with a Packet object.
     *
     * @param source Source object which is broadcasting the event.
     * @param packet Packet which this event is about
     */
    public PacketEvent(Object source,Packet packet)
    {
	this(source);
	this.packet=packet;
    }

    /**
     * <code>getPacket</code> returns the packet which is the topic of this
     * event.
     *
     * @return a <code>Packet</code> value, or null if none provided.
     */
    public Packet getPacket()
    {
	return packet;
    }
}
