package org.jabber.jabberbeans;

import org.jabber.jabberbeans.*;
import org.jabber.jabberbeans.util.JID;
import org.jabber.jabberbeans.Extension.*;

import java.io.Serializable;
import java.util.Enumeration;
import java.util.Vector;
import java.util.*;
import java.io.*;

import java.lang.InstantiationException;



public class PresenceBean implements Serializable
{
	//A way of implementing a debug mode
	private boolean debug = false;
	
	//Create a connection bean.
	private ConnectionBean cb = null;
	
	//Create a list of the presence listeners
	private Vector presenceListeners = new Vector();
	
	//Create a list of the user presences with resources
	//Map jidTree = Collections.synchronizedMap(new TreeMap(...));
	private Hashtable jidTree = new Hashtable();
	
	//Map of the presence packets to ignore
	private Vector blackList = new Vector();
	
	//boolean that handles the state of the blacklist
	private boolean blackListEnable = false;
	private int blackListCounter = 0;
	
	//Create a presence listener
	private PresencePacketListener listener = null;
	
	
	
	//Do nothing Constructor
	public PresenceBean(){}
	
	//class def
	class PresencePacketListener implements PacketListener
	{
		public void receivedPacket(PacketEvent pe)
		{
			try
			{
				//Test for presence packets
				if(!(pe.getPacket() instanceof Presence))
					return;

				//We need a presence object
				Presence p;
				try
				{
					p = (Presence) pe.getPacket();
					
					//Ignore blacklisted presence
					if(blackListEnable)
					{
						if(blackList.contains(p.getFromAddress().toSimpleString()))
							return;
					}
					
					if(debug)
						System.err.println("Packet to String: " + p.toString());
				}
				catch(ClassCastException e) 
				{ 
					System.err.println("Error in Presence Bean.  Could not cast Presence Packet");
					return; 
				}


				String type = p.getType();
				JID addy = p.getFromAddress();
				String state = p.getStateShow();
				String status = p.getStatus();
				
				JID short_address = JID.fromString(addy.toSimpleString());
				JID full_address = addy;
				boolean user_contained = jidTree.containsKey(short_address);


				//Debug output to determine what is coming in and out.
				if(debug)
				{					
					System.err.println("Short: " + short_address);
					System.err.println("Full: " + full_address);
					System.err.println("Type:  " + type + "  Addy:  " + addy.toPrettyString() + "  State:  " + state + "  Status:  " + status);
				}
				


				if(type == (null) || "available".equals(type)) 
				{//user has come online or changed state or status

					//Only allow an addition if the list doesn't contain the element
					//Otherwise do a compare before adding or removing
					if(!user_contained)
					{//user has come online for the first time.

						//notification
						if(debug)
							System.err.println("Adding user the first time.");

						//create the one time usernode.  This contains individual resources
						PresenceUserNode node = new PresenceUserNode(addy, state, status);

						if(debug)
							System.err.println("Node: " + node);

						//place node in tree
						jidTree.put(short_address, node);

						//fire the changed presence handler with a copy of the current list of
						//online users
						fireChangedPresence(jidTree, p, node, "online");

						//notification
						if(debug)
							System.err.println("Fired changed presence event.");

					}
					else
					{//a new resource has come online, or an existing one has bee modified

						//check for a different resource, or change the state info
						PresenceUserNode node = (PresenceUserNode)jidTree.get(short_address);

						if(node.containsResource(full_address))
						{//the node contains the resource, so we change the state, and status info

							//notification
							if(debug)
								System.err.println(full_address + " adjusted for state info.");

							//set the resources state
							node.setState(addy, state);

							//set the resources status
							node.setStatus(addy, status);

							//fire the changed presence handler with a copy of the current list of
							//online users
							fireChangedPresence(jidTree, p, node, "status");

						}
						else
						{//the node does NOT contain the resource, so we add it

							//notification
							if(debug)
								System.err.println(addy + " added as a resource to the user node.");

							//add a resource to the user's node
							node.addResource(addy, state, status);

							System.err.println("Adding resource " + short_address + ".\nResources: " + node.getNumResources());

							//fire the changed presence handler with a copy of the current list of
							//online users
							fireChangedPresence(jidTree, p, node, "online");

						}

						
						//notification
						if(debug)
							System.err.println("Fired changed presence event.");

					}				
				}
				else if("unavailable".equals(type)) 
				{//user resource has gone offline
				
					PresenceUserNode node = null;
					
					if(user_contained)
					{//Only allow a remove if the list actually contains the element

						//get the user node so we can test for multiple resources
						node = (PresenceUserNode)jidTree.get(short_address);

						if(node.getNumResources() <= 1)
						{//we have a single resource, so we can remove the entire reference

							//remove the user's node from the running list of online users
							jidTree.remove(short_address);

							if(debug)
								System.err.println("Removing resource " + short_address);

						}
						else
						{//we have more than one resource, so we must remove just it.

							//notification
							if(debug)
								System.err.println("Removing resource " + full_address + ".\nResources: " + node.getNumResources());

							//remove the resource from the user's node
							node.removeResource(full_address);

							if(debug)
								System.err.println("Removing resource " + full_address + ".\nResources: " + node.getNumResources());

						}
					//fire the changed presence handler with a copy of the current list of
					//online users
					fireChangedPresence(jidTree, p, node, "unavailable");
					}
					
				}
				else if("subscribe".equals(type))
				{//user wishes to subscribe to our presence

					if(debug)
						System.err.println("Subscription request from " + addy.toPrettyString());

					//fire the subscribe event handler
					fireSubscribe(p);

				}
				else if("subscribed".equals(type))
				{//user has ok'd our viewing of their presence

					if(debug)
						System.err.println("Subcription request succeeded from " + addy.toPrettyString());

					//fire the subscribed event handler
					fireSubscribed(p);

				}
				else if("unsubscribe".equals(type))
				{//user wishes to stop viewing out presence

					if(debug)
						System.err.println(addy.toPrettyString() + " is unsubscribing from our presence.");

					//fire the unsubscribe event handler
					fireUnsubscribe(p);

				}
				else if("unsubscribed".equals(type))
				{//user has barred us from viewing their presence

					if(debug)
						System.err.println(addy.toPrettyString() + " has unsubscribed us from their presence.");

					//remove the user's reference from our running list of available and online users
					jidTree.remove(short_address);

					//fire the unsubscribed event handler
					fireUnsubscribed(p);

				}
				else// if("error".equals(type))
				{//we've received some sort of error packet from the user or their server

					if(debug)
						System.err.println("Error presence packet recieved");

					//fire the error event handler
					fireError(p);

				}
			}
			catch(Exception e)
			{e.printStackTrace();}
		}

		//never used
		public void sentPacket(PacketEvent pe){}	
		public void sendFailed(PacketEvent pe){}		
	}	

	//Set the connection bean
	/*
	 * <code>setConnBean</code> This will set the connection bean that we read packets from.
	 *
	 * @param connbean a <code>ConnectionBean</code> used for reading packets off of.
	 */
	public void setConnBean(ConnectionBean connbean)
	{
		this.cb = connbean;
		listener = new PresencePacketListener();
		cb.addPacketListener(listener);
	}
	
	//Return the connection used in the bean
	/*
	 * <code>getConnBean</code> This will return the connection bean we're using.
	 *
	 */
	public ConnectionBean getConnBean()
	{return this.cb;}
	
	public Hashtable getJIDTree()
	{return this.jidTree;}
	
	/*
	 * <code>getDebug</code> returns the debug status of the bean
	 */
	public boolean getDebug()
	{return this.debug;}
	
	/*
	 * <code>setDebug</code> sets the debug status of the bean
	 *
	 * @param b <code>boolean</code> takes a boolean and sets the debug state
	 */
	public void setDebug(boolean b)
	{this.debug = b;}
	
	public void toPrintString()
	{
		Collection collection = jidTree.values();
		Iterator iterator = collection.iterator();

		while(iterator.hasNext())
		{
			PresenceUserNode node = (PresenceUserNode)iterator.next();			
			System.err.println(node.toString());			
		}
	}
	
	//Changed Presence event
	public void fireChangedPresence(Hashtable t, Presence p, PresenceUserNode n, String s)
	{
		try
		{
			Vector broadcast = (Vector)presenceListeners.clone();
			for(Enumeration e = broadcast.elements(); e.hasMoreElements();)
			((PresenceListener)e.nextElement()).changedPresence(t, p, n, s);
		}
		catch(Exception e)
		{e.printStackTrace();}
	}
	
	//Subscribe event
	public void fireSubscribe(Presence p)
	{
		try
		{
			Vector broadcast = (Vector)presenceListeners.clone();
			for(Enumeration e = broadcast.elements(); e.hasMoreElements();)
			((PresenceListener)e.nextElement()).subscribe(p);
		}
		catch(Exception e)
		{e.printStackTrace();}
	}

	//Subscribed event
	public void fireSubscribed(Presence p)
	{
		try
		{
			Vector broadcast = (Vector)presenceListeners.clone();
			for(Enumeration e = broadcast.elements(); e.hasMoreElements();)
			((PresenceListener)e.nextElement()).subscribed(p);
		}
		catch(Exception e)
		{e.printStackTrace();}
	}
	
	//Unsubscribe event
	public void fireUnsubscribe(Presence p)
	{
		try
		{
			Vector broadcast = (Vector)presenceListeners.clone();
			for(Enumeration e = broadcast.elements(); e.hasMoreElements();)
			((PresenceListener)e.nextElement()).unsubscribe(p);
		}
		catch(Exception e)
		{e.printStackTrace();}
	}
	
	//Unsubscribed event
	public void fireUnsubscribed(Presence p)
	{
		try
		{
			Vector broadcast = (Vector)presenceListeners.clone();
			for(Enumeration e = broadcast.elements(); e.hasMoreElements();)
			((PresenceListener)e.nextElement()).unsubscribed(p);
		}
		catch(Exception e)
		{e.printStackTrace();}
	}
	
	//Error event
	public void fireError(Presence p)
	{
		try
		{
			Vector broadcast = (Vector)presenceListeners.clone();
			for(Enumeration e = broadcast.elements(); e.hasMoreElements();)
			((PresenceListener)e.nextElement()).error(p);
		}
		catch(Exception e)
		{e.printStackTrace();}
	}
	
	//Add a presence listener
	public synchronized void addPresenceListener(PresenceListener l)
	{
		if(!presenceListeners.contains(l))
			presenceListeners.addElement(l);
	}

	//Remove a presence listener
	public synchronized void delPresenceListener(PresenceListener l)
	{ 
		if(presenceListeners.contains(l))
			presenceListeners.removeElement(l); 
	}
	
	
	/*
	 * <code>addToBlacklist</code> adds a <code>JID</code> to the blacklist.
	 * We ignore blacklisted jids
	 *
	 * @param addy is the <code>JID</code> to add to the blacklist
	 */
	public void addToBlacklist(JID addy)
	{
		if(!blackList.contains(addy.toSimpleString()))
			blackList.addElement(addy.toSimpleString());
	}
	
	
	/*
	 * <code>removeFromBlacklist</code> removes a <code>JID</code> from the blacklist.
	 * We ignore blacklisted jids
	 *
	 * @param addy is the <code>JID</code> to remove from the blacklist
	 */
	public void removeFromBlacklist(JID addy)
	{
		if(blackList.contains(addy.toSimpleString()))
			blackList.removeElement(addy.toSimpleString());
	}
	
	
	/*
	 * <code>setBlackListEnable</code> sets the state of blacklisting
	 * Do note that blacklisting is <b>NOT</b> resource specific.
	 *
	 * @param value is a <code>boolean</code> that toggles the state of blacklisting
	 */
	public void setBlacklistEnable(boolean value)
	{
		if(value)
			blackListCounter++;
		else 
			if(blackListCounter >= 1)
				blackListCounter--;
		
		//So long as we have one black listed jid
		if(blackListCounter >= 1)
			blackListEnable = true;
		else
			blackListEnable = false;
	}
	
	
	/*
	 * <code>getBlackListEnable</code> returns the state of blacklisting
	 */
	public boolean getBlacklistEnable()
	{return blackListEnable;}		
}