/*
 *   License
 *
 * The contents of this file are subject to the Jabber Open Source License
 * Version 1.0 (the "License").  You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License.  You
 * may obtain a copy of the License at http://www.jabber.com/license/ or at
 * http://www.opensource.org/.  
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 *   Copyrights
 *
 * Portions created by or assigned to Jabber.com, Inc. are 
 * Copyright (c) 2000 Jabber.com, Inc.  All Rights Reserved.  Contact
 * information for Jabber.com, Inc. is available at http://www.jabber.com/.
 *
 * Portions Copyright (c) 1999-2000 David Waite 
 *
 *   Acknowledgements
 * 
 * Special thanks to the Jabber Open Source Contributors for their
 * suggestions and support of Jabber.
 * 
 *   Changes
 *
 */

package org.jabber.jabberbeans;

import org.jabber.jabberbeans.Extension.Roster;
import java.io.Serializable;

/**
 * RosterAdapter is an abstract class you can extend to get any 
 * roster changes as notifications to your code.
 * <p>
 *
 * @author  David Waite <a href="mailto:dwaite@jabber.com">
 *                      <i>&lt;dwaite@jabber.com&gt;</i></a>
 * @author  $Author: mass $
 * @version $Revision: 1.10 $
 */
public abstract class RosterAdapter
    implements RosterListener, Serializable
{
    /**
     * The <code>changedRoster</code> event indicates that the roster has
     * received an update. The change is passed as the contents of the 
     * roster extension
     *
     * @param r a <code>Roster</code> with changes to the in-
     * place list
     */
    public void changedRoster(Roster r)
    {};

    /**
     * The <code>ReplacedRoster</code> event indicates that there was a
     * complete reload of the roster. It should always be equivalent to a 
     * changedRoster event, because the roster passed is the full new roster.
     *
     * @param r a <code>Roster</code> from the RosterBean's cache
     */
    public void ReplacedRoster(Roster r)
    {};
}
