/*
 *   License
 *
 * The contents of this file are subject to the Jabber Open Source License
 * Version 1.0 (the "License").  You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License.  You
 * may obtain a copy of the License at http://www.jabber.com/license/ or at
 * http://www.opensource.org/.  
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 *   Copyrights
 *
 * Portions created by or assigned to Jabber.com, Inc. are 
 * Copyright (c) 2000 Jabber.com, Inc.  All Rights Reserved.  Contact
 * information for Jabber.com, Inc. is available at http://www.jabber.com/.
 *
 * Portions Copyright (c) 1999-2000 David Waite 
 *
 *   Acknowledgements
 * 
 * Special thanks to the Jabber Open Source Contributors for their
 * suggestions and support of Jabber.
 * 
 *   Changes
 *
 */

package org.jabber.jabberbeans;

import org.jabber.jabberbeans.Extension.Roster;

/**
 * RosterListener is an interface you can implement in a client to get any 
 * roster changes as notifications to your code.
 * <p>
 *
 * @see RosterAdapter
 *
 * @author  David Waite <a href="mailto:dwaite@jabber.com">
 *                      <i>&lt;dwaite@jabber.com&gt;</i></a>
 * @author  $Author: mass $
 * @version $Revision: 1.10 $
 */
public interface RosterListener
{
    /**
     * The <code>changedRoster</code> event is fired when there has been a
     * change to the roster state. The passed-in Roster is a 'list' of
     * changes. The cached value in the RosterBean is the new, full list.
     *
     * @param r a <code>Roster Extension</code> describing the changes
     */
    void changedRoster(Roster r);

    /**
     * The <code>replacedRoster</code> event is fired when a completely new
     * roster has replaced the existing one. The passed-in Roster is a
     * full new list of Roster entries. The cached value in the RosterBean
     * is equivalent to this value.
     *
     * @param r a <code>Roster Extension</code> containing the new roster
     */
    void replacedRoster(Roster r);
}
