/*
 *   License
 *
 * The contents of this file are subject to the Jabber Open Source License
 * Version 1.0 (the "License").  You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License.  You
 * may obtain a copy of the License at http://www.jabber.com/license/ or at
 * http://www.opensource.org/.  
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 *   Copyrights
 *
 * Portions created by or assigned to Jabber.com, Inc. are 
 * Copyright (c) 2000 Jabber.com, Inc.  All Rights Reserved.  Contact
 * information for Jabber.com, Inc. is available at http://www.jabber.com/.
 *
 *   Acknowledgements
 * 
 * Special thanks to the Jabber Open Source Contributors for their
 * suggestions and support of Jabber.
 * 
 *   Changes
 *
 */

package org.jabber.jabberbeans;

import org.jabber.jabberbeans.util.JID;

/**
 * Class which represents an XMLStream header - this names the overall
 * namespace (format) of the XML data being transmitted and received.
 *
 * This is also the only packet which isn't really a 'packet' per-se - it
 * isn't closed. It is instead the header which is sent on first connect
 * to verify this is indeed a Jabber server, and set the framework for
 * communication
 *
 * @author  David Waite <a href="mailto:dwaite@jabber.com">
 *                      <i>&lt;dwaite@jabber.com&gt;</i></a>
 * @author  $Author: mass $
 * @version $Revision: 1.9 $
 */
public class XMLStreamHeader
    extends XMLData
    implements Packet
{
    /** <code>XMLNS</code> holds the namespace of the protocol being spoken. */
    private String XMLNS;

    /** <code>id</code> is the reserved XML id, it also holds the session ID
     * which is prepended to any keys or passwords and hashed to do any
     * digest-based authentication
     */
    private String id;

    private JID toAddress;

    private JID fromAddress;


    /**
     * Creates a new <code>XMLStreamHeader</code> instance.
     *
     * @param server server we are connecting to (specific virtualhost)
     * @param xmlns namespace of the protocol
     * @param identifier identifier used as session ID
     */
    public XMLStreamHeader(XMLStreamHeaderBuilder builder)
    {
	XMLNS=builder.getXMLNS();
	id=builder.getIdentifier();
	toAddress=builder.getToAddress();
	fromAddress=builder.getFromAddress();
    }

    public String getXMLNS()
    {
	return XMLNS;
    }

    public String getIdentifier()
    {
	return id;
    }

    public JID getToAddress()
    {
	return toAddress;
    }

    public JID getFromAddress()
    {
	return fromAddress;
    }

    /**
     * <code>appendItem</code> appends the XML representation of the
     * current packet data to the specified <code>StringBuffer</code>.
     *
     * @param retval The <code>StringBuffer</code> to append to
     */
    public void appendItem(StringBuffer retval)
    {
	retval.append
	    ("<stream:stream xmlns:stream=" +
	     "\"http://etherx.jabber.org/streams\"");
	appendAttrib(retval,"xmlns",XMLNS);
	appendAttrib(retval,"to",toAddress);
	appendAttrib(retval,"from",fromAddress);
	appendAttrib(retval,"id",id);
	retval.append(">");
    }
}
