/*
 *   License
 *
 * The contents of this file are subject to the Jabber Open Source License
 * Version 1.0 (the "License").  You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License.  You
 * may obtain a copy of the License at http://www.jabber.com/license/ or at
 * http://www.opensource.org/.  
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 *   Copyrights
 *
 * Portions created by or assigned to Jabber.com, Inc. are 
 * Copyright (c) 2000 Jabber.com, Inc.  All Rights Reserved.  Contact
 * information for Jabber.com, Inc. is available at http://www.jabber.com/.
 *
 * Portions Copyright (c) 1999-2000 David Waite 
 *
 *   Acknowledgements
 * 
 * Special thanks to the Jabber Open Source Contributors for their
 * suggestions and support of Jabber.
 * 
 *   Changes
 *
 */

package org.jabber.jabberbeans.sax.Extension;

import org.jabber.jabberbeans.*;
import org.jabber.jabberbeans.Extension.*;

/**
 * <code>DefaultExtension</code> is a backend-specific handler for extensions
 * which are not known. Like all other Extension-derived objects, the one real
 * requirement is that it be able to render itself back as equivalent XML.
 * <p>
 * Note: It is recommended that this class <b>not</b> be programmed 
 * directly for - it is backend specific, and could change substantially in
 * the future - plus a serialized representation does not result in 
 * maintainable code
 *
 * @author  David Waite <a href="mailto:dwaite@jabber.com">
 *                      <i>&lt;dwaite@jabber.com&gt;</i></a>
 * @author  $Author: mass $
 * @version $Revision: 1.11 $ 
 *
 * @see MessageExtension
 * @see QueryExtension
 * @see PresenceExtension
 */
public class DefaultExtension
    extends XMLData
    implements MessageExtension, 
	       QueryExtension,  
               PresenceExtension,
               Packet
{
    /** XML Namespace string*/
    private String xmlns;

    /** XML base element name*/
    private String element;

    /** Full XML from element start to finish*/
    private String xmlSnippet;
    
    /** Creates a new <code>DefaultExtension</code> instance.
     *
     * @param XMLNS the XML Namespace
     * @param XMLSnippet the full XML to be handled by the extension.
     * @exception InstantiationException if either parameter is not passed in 
     * correctly
     */
    public DefaultExtension(String Element, String XMLNS, String XMLSnippet) 
	throws InstantiationException
    {
	element=Element;
	xmlns=XMLNS;
	xmlSnippet=XMLSnippet;
    }
    
    /** <code>getXMLNamespace</code> returns the XML namespace
     *
     * @return a <code>String</code> holding the XML Namespace
     */
    public String getXMLNamespace()
    { return xmlns; }

    /** Returns the XML representation for the data contained within.
     *
     * @return a <code>String</code> in XML.
     */
    public void appendItem(StringBuffer retval)
    { retval.append(xmlSnippet); }
}
