/*
 *   License
 *
 * The contents of this file are subject to the Jabber Open Source License
 * Version 1.0 (the "License").  You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License.  You
 * may obtain a copy of the License at http://www.jabber.com/license/ or at
 * http://www.opensource.org/.  
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 *   Copyrights
 *
 * Portions created by or assigned to Jabber.com, Inc. are 
 * Copyright (c) 2000 Jabber.com, Inc.  All Rights Reserved.  Contact
 * information for Jabber.com, Inc. is available at http://www.jabber.com/.
 *
 * Portions Copyright (c) 1999-2000 David Waite 
 *
 *   Acknowledgements
 * 
 * Special thanks to the Jabber Open Source Contributors for their
 * suggestions and support of Jabber.
 * 
 *   Changes
 *
 */

package org.jabber.jabberbeans.sax.Extension;

import org.jabber.jabberbeans.util.JID;
import org.jabber.jabberbeans.Extension.AgentBuilder;
import org.jabber.jabberbeans.Extension.IQAgentsBuilder;
import org.jabber.jabberbeans.sax.SubHandler;
import org.xml.sax.*;

/**
 * Handler class to build jabber:iq:agents objects
 *
 * @author  David Waite <a href="mailto:dwaite@jabber.com">
 *                      <i>&lt;dwaite@jabber.com&gt;</i></a>
 * @author  $Author: mass $
 * @version $Revision: 1.6 $ 
 */
public class IQAgentsHandler
    extends SubHandler
{
    /** builder for IQAgents object */
    private IQAgentsBuilder listBuilder;

    /** builder used to construct the Agent objects that make up IQAgents */
    private AgentBuilder itemBuilder;

    /** used to save data between element tags */
    StringBuffer elementChars;

    /**
     * Creates a new <code>IQAgentsHandler</code> instance.
     */
    public IQAgentsHandler()
    {
	super();
	listBuilder=new IQAgentsBuilder();
	itemBuilder=new AgentBuilder();
    }

    /**
     * This is an exact copy of the characters function in the main handler
     *
     * @param ch character string detected
     * @param start start position
     * @param length length of string
     * @exception SAXException thrown on error
     */
    public void characters(char[] ch, int start, int length)
	throws SAXException
    {elementChars.append(ch,start,length);}

    /**
     * Gets called when the underlying engine decides to pass an entity and
     * all sub-entities off to your subhandler.<p>
     *
     * Upon seeing the element that this subhandler handles, we call this
     * constructor, passing in the attributes.
     *
     * @param name name of the element which we are handling.
     * @param attributes list of attributes on this element
     */
    protected void startHandler(String name,AttributeList attributes)
	throws SAXException
    {
	elementChars=new StringBuffer();
	
	listBuilder.reset();
	itemBuilder.reset();

    }
    /**
     * <code>handleStartElement</code> is overloaded by the new class to
     * provide logic to handle the element code.
     *
     * @param name a <code>String</code> value
     * @param attributes an <code>AttributeList</code> value
     * @exception SAXException if an error occurs
     */
    protected void handleStartElement(String name, 
				      AttributeList attributes)
	throws SAXException
    {
	elementChars=new StringBuffer();

	if (!name.equals("agent"))
	    return;
	itemBuilder.reset();
	itemBuilder.setJID
	    (JID.fromString(attributes.getValue("jid")));
    }
    
    /**
     * <code>handleEndElement</code> is overloaded by the new class to
     * provide logic to handle element code.
     *
     * @param name a <code>String</code> value
     * @exception SAXException if an error occurs
     */
    protected void handleEndElement(String name)
	throws SAXException
    {
	if (name.equals("name"))
	    itemBuilder.setName(new String(elementChars));
	if (name.equals("description"))
	    itemBuilder.setDescription(new String(elementChars));
	if (name.equals("service"))
	    itemBuilder.setService(new String(elementChars));
	if (name.equals("transport"))
	    itemBuilder.setTransport(new String(elementChars));

	if (name.equals("register"))
	    itemBuilder.setRegister(true);
	if (name.equals("search"))
	    itemBuilder.setSearchable(true);

	try
	{
	    if (name.equals("agent"))
		listBuilder.addAgent(itemBuilder.build());
	}
	catch (InstantiationException e)
	{
	    e.fillInStackTrace();
	    throw new SAXException(e);
	}
    }

    /**
     * Stophandler is the same as end element, except that it is called saying
     * that the subhandler is no longer in scope.
     *
     * @param Object a value being returned to the parent - the parent is 
     * meant to interpret this result.
     */
    protected Object stopHandler(String name)
	throws SAXException
    {
	try
	{
	    return listBuilder.build();
	}
	catch (InstantiationException e)
	{
	    throw new SAXException(e);
	}
    }

    /**
     * <code>receiveChildData</code> is called when a child handler exits,
     * returning control to this code. The now-defunct handler along with the
     * data object are both returned.
     *
     * @param subHandler a <code>SubHandler</code> value
     * @param o an <code>Object</code> value
     */
    protected void receiveChildData(SubHandler subHandler,Object o)
    {/* no children, do nothing*/}
}
