/*
 *   License
 *
 * The contents of this file are subject to the Jabber Open Source License
 * Version 1.0 (the "License").  You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License.  You
 * may obtain a copy of the License at http://www.jabber.com/license/ or at
 * http://www.opensource.org/.  
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 *   Copyrights
 *
 * Portions created by or assigned to Jabber.com, Inc. are 
 * Copyright (c) 2000 Jabber.com, Inc.  All Rights Reserved.  Contact
 * information for Jabber.com, Inc. is available at http://www.jabber.com/.
 *
 * Portions Copyright (c) 1999-2000 David Waite 
 *
 *   Acknowledgements
 * 
 * Special thanks to the Jabber Open Source Contributors for their
 * suggestions and support of Jabber.
 * 
 *   Changes
 *
 */

package org.jabber.jabberbeans.sax.Extension;

import org.jabber.jabberbeans.Extension.*;
import org.jabber.jabberbeans.sax.SubHandler;
import org.xml.sax.SAXException;
import org.xml.sax.AttributeList;

/**
 * Handler class to build jabber:iq:autoupdate objects
 *
 * @author  David Waite <a href="mailto:dwaite@jabber.com">
 *                      <i>&lt;dwaite@jabber.com&gt;</i></a>
 * @author  $Author: mass $
 * @version $Revision: 1.6 $ 
 */
public class IQAutoUpdateHandler
    extends SubHandler
{
    /** used to capture data between element tags */
    StringBuffer elementChars;

    /** used to build the jabber:iq:autoupdate list of update objects */
    IQAutoUpdateBuilder listBuilder;
    
    /** builder for creating individual UpdateInfo items */
    UpdateInfoBuilder itemBuilder;

    /**
     * Creates a new <code>IQAutoUpdateHandler</code> instance.
     */
    public IQAutoUpdateHandler() 
    {
	super();
	listBuilder=new IQAutoUpdateBuilder();
	itemBuilder=new UpdateInfoBuilder();
    }

    /**
     * This is an exact copy of the characters function in the main handler
     *
     * @param ch character string detected
     * @param start start position
     * @param length length of string
     * @exception SAXException thrown on error
     */
    public void characters(char[] ch, int start, int length)
	throws SAXException
    {elementChars.append(ch,start,length);}

    /**
     * Gets called when the underlying engine decides to pass an entity and
     * all sub-entities off to your subhandler.<p>
     *
     * Upon seeing the element that this subhandler handles, we call this
     * constructor, passing in the attributes.
     *
     * @param name name of the element which we are handling.
     * @param attributes list of attributes on this element
     */
    protected void startHandler(String name,AttributeList attributes)
	throws SAXException
    {
	listBuilder.reset();
    }

    /**
     * <code>handleStartElement</code> is overloaded by the new class to
     * provide logic to handle the element code.
     *
     * @param name a <code>String</code> value
     * @param attributes an <code>AttributeList</code> value
     * @exception SAXException if an error occurs
     */
    protected void handleStartElement(String name, 
				      AttributeList attributes)
	throws SAXException
    {
	elementChars=new StringBuffer();
	if ((name.equals("beta"))||
	    (name.equals("dev"))||
	    (name.equals("release")))
	{
	    itemBuilder.reset();
	    itemBuilder.setType(name);
	    itemBuilder.setPriority(attributes.getValue("priority"));
	}
    }
    
    /**
     * <code>handleEndElement</code> is overloaded by the new class to
     * provide logic to handle element code.
     *
     * @param name a <code>String</code> value
     * @exception SAXException if an error occurs
     */
    protected void handleEndElement(String name)
	throws SAXException
    {
	if (name.equals("ver"))
	    itemBuilder.setVersion(new String(elementChars));
	if (name.equals("url"))
	    itemBuilder.setURL(new String(elementChars));
    }

    /**
     * Stophandler is the same as end element, except that it is called saying
     * that the subhandler is no longer in scope.
     *
     * @param Object a value being returned to the parent - the parent is 
     * meant to interpret this result.
     */
    protected Object stopHandler(String name)
	throws SAXException
    {
	return listBuilder.build();
    }

    /**
     * <code>receiveChildData</code> is called when a child handler exits,
     * returning control to this code. The now-defunct handler along with the
     * data object are both returned.
     *
     * @param subHandler a <code>SubHandler</code> value
     * @param o an <code>Object</code> value
     */
    protected void receiveChildData(SubHandler subHandler,Object o)
    {/* no children, do nothing*/}
}
 
