/*
 *   License
 *
 * The contents of this file are subject to the Jabber Open Source License
 * Version 1.0 (the "License").  You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License.  You
 * may obtain a copy of the License at http://www.jabber.com/license/ or at
 * http://www.opensource.org/.  
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 *   Copyrights
 *
 *	 Shawn Wilton
 */

package org.jabber.jabberbeans.sax.Extension;

//import java.net.*;
import org.jabber.jabberbeans.Extension.*;
import org.jabber.jabberbeans.util.*;
import org.jabber.jabberbeans.sax.SubHandler;
import org.xml.sax.SAXException;
import org.xml.sax.AttributeList;

/**
 * Handler class to build jabber:iq:browse objects
 *
/*
 * @author  Shawn Wilton <a href="mailto:shawn@black9.net">
 *                      <i>&lt;shawn@black9.net&gt;</i></a>
 * @author  $Author: XB $
 * @version $Revision: 0.0.0.1 $
 */


public class IQBrowseHandler extends SubHandler
{
	/** used to capture data between element tags */
	private StringBuffer elementChars;

	/** builder for IQPassExtension objects */
	private IQBrowseBuilder builder;


	/*
	 * Creates a new <code>IQBrowseHandler</code> instance.
	 */
	public IQBrowseHandler()
	{
		super();
		builder=new IQBrowseBuilder();
	}


	/*
	 * This is an exact copy of the characters function in the main handler
	 *
	 * @param ch character string detected
	 * @param start start position
	 * @param length length of string
	 * @exception SAXException thrown on error
	 */
	public void characters(char[] ch, int start, int length) throws SAXException
	{elementChars.append(ch,start,length);}

	
	/*
	 * Gets called when the underlying engine decides to pass an entity and
	 * all sub-entities off to your subhandler.<p>
	 *
	 * Upon seeing the element that this subhandler handles, we call this
	 * constructor, passing in the attributes.
	 *
	 * @param name name of the element which we are handling.
	 * @param attributes list of attributes on this element
	 */
	protected void startHandler(String name, AttributeList attributes) throws SAXException
	{
		elementChars=new StringBuffer();
		builder.reset();
		
		//General element category
		builder.setCategory(name);
		
		//Determine if this is an iq browse packet
		if(attributes.getValue("xmlns") != null)
			builder.setIQ(true);
		
		//Type of packet
		if(attributes.getValue("type") != null)
			builder.setType(attributes.getValue("type"));
		
		//Friendly name
		if(attributes.getValue("name") != null)
			builder.setName(attributes.getValue("name"));
		
		//Address of the item
		if(attributes.getValue("jid") != null)
			builder.setJID(JID.fromString(attributes.getValue("jid")));		
	}
	
	
	/*
	 * <code>handleStartElement</code> is overloaded by the new class to
	 * provide logic to handle the element code.
	 *
	 * @param name a <code>String</code> value
	 * @param attributes an <code>AttributeList</code> value
	 * @exception SAXException if an error occurs
	 */
	protected void handleStartElement(String name, AttributeList attributes) throws SAXException
	{			
		elementChars=new StringBuffer();

		//Start new handler for items that *may* be containers, but never for namespaces "ns".
		if(!"ns".equals(name))
			setChildSubHandler(new IQBrowseHandler(), name, attributes);
	}


	/*
	 * <code>handleEndElement</code> is overloaded by the new class to
	 * provide logic to handle element code.
	 *
	 * @param name a <code>String</code> value
	 * @exception SAXException if an error occurs
	 */
	protected void handleEndElement(String name) throws SAXException
	{
		if("ns".equals(name))
			builder.addNameSpace(new String(elementChars));
	}

	
	/*
	 * Stophandler is the same as end element, except that it is called saying
	 * that the subhandler is no longer in scope.
	 *
	 * @param Object a value being returned to the parent - the parent is 
	 * meant to interpret this result.
	 */
	protected Object stopHandler(String name) throws SAXException
	{
		try{return builder.build();}
		catch (InstantiationException e)
		{
			e.fillInStackTrace();
			throw new SAXException(e);
		}
	}
	
	
	/*
	 * <code>receiveChildData</code> is called when a child handler exits,
	 * returning control to this code. The now-defunct handler along with the
	 * data object are both returned.
	 *
	 * @param subHandler a <code>SubHandler</code> value
	 * @param o an <code>Object</code> value
	 */
	protected void receiveChildData(SubHandler subHandler,Object o)
	{
		//Add the returned object to the child vector
		builder.addChild((BrowseItem)o);
	}
}
