/*
 *   License
 *
 * The contents of this file are subject to the Jabber Open Source License
 * Version 1.0 (the "License").  You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License.  You
 * may obtain a copy of the License at http://www.jabber.com/license/ or at
 * http://www.opensource.org/.  
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 *   Copyrights
 *
 * Portions created by or assigned to Jabber.com, Inc. are 
 * Copyright (c) 2000 Jabber.com, Inc.  All Rights Reserved.  Contact
 * information for Jabber.com, Inc. is available at http://www.jabber.com/.
 *
 * Portions Copyright (c) 1999-2000 David Waite 
 *
 *   Acknowledgements
 * 
 * Special thanks to the Jabber Open Source Contributors for their
 * suggestions and support of Jabber.
 * 
 *   Changes
 *
 */

package org.jabber.jabberbeans.sax.Extension;

import org.jabber.jabberbeans.util.JID;
import org.jabber.jabberbeans.Extension.*;
import org.jabber.jabberbeans.sax.SubHandler;
import org.xml.sax.SAXException;
import org.xml.sax.AttributeList;

/*
 * Handler class to build jabber:x:conference objects.
 *
 */
public class XConferenceHandler extends SubHandler
{
	/* buffer used to save data between element tags */
	StringBuffer elementChars;

	/* builder to create XDelay extension objects */
	XConferenceBuilder builder;

	/*
	 * Creates a new <code>XDelayHandler</code> instance.
	 */
	public XConferenceHandler() 
	{
		super();
		builder=new XConferenceBuilder();
	}

	/*
	 * This is an exact copy of the characters function in the main handler
	 *
	 * @param ch character string detected
	 * @param start start position
	 * @param length length of string
	 * @exception SAXException thrown on error
	 */
	public void characters(char[] ch, int start, int length) throws SAXException
	{elementChars.append(ch,start,length);}

	/*
	 * Gets called when the underlying engine decides to pass an entity and
	 * all sub-entities off to your subhandler.<p>
	 *
	 * Upon seeing the element that this subhandler handles, we call this
	 * constructor, passing in the attributes.
	 *
	 * @param name name of the element which we are handling.
	 * @param attributes list of attributes on this element
	 */
	protected void startHandler(String name,AttributeList attributes)	throws SAXException
	{
		builder.reset();
		elementChars=new StringBuffer();

		builder.setAddress(JID.fromString(attributes.getValue("jid")));
	}

	/*
	 * Stophandler is the same as end element, except that it is called saying
	 * that the subhandler is no longer in scope.
	 *
	 * @param Object a value being returned to the parent - the parent is 
	 * meant to interpret this result.
	 */
	protected Object stopHandler(String name)	throws SAXException
	{
		try
		{return builder.build();}
		catch (InstantiationException e)
		{
			e.fillInStackTrace();
			throw new SAXException(e);
		}
	}

	/**
	 * <code>handleStartElement</code> is overloaded by the new class to
	 * provide logic to handle the element code.
	 *
	 * @param name a <code>String</code> value
	 * @param attributes an <code>AttributeList</code> value
	 * @exception SAXException if an error occurs
	 */
	protected void handleStartElement(String name, AttributeList attributes) throws SAXException
	{}

	/**
	 * <code>handleEndElement</code> is overloaded by the new class to
	 * provide logic to handle element code.
	 *
	 * @param name a <code>String</code> value
	 * @exception SAXException if an error occurs
	 */
	protected void handleEndElement(String name) throws SAXException
	{}

	/**
	 * <code>receiveChildData</code> is called when a child handler exits,
	 * returning control to this code. The now-defunct handler along with the
	 * data object are both returned.
	 *
	 * @param subHandler a <code>SubHandler</code> value
	 * @param o an <code>Object</code> value
	 */
	protected void receiveChildData(SubHandler subHandler,Object o)
	{/* no children, do nothing*/}
}
