/*
 *   License
 *
 * The contents of this file are subject to the Jabber Open Source License
 * Version 1.0 (the "License").  You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License.  You
 * may obtain a copy of the License at http://www.jabber.com/license/ or at
 * http://www.opensource.org/.  
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 *   Copyrights
 *
 * Portions created by or assigned to Jabber.com, Inc. are 
 * Copyright (c) 2000 Jabber.com, Inc.  All Rights Reserved.  Contact
 * information for Jabber.com, Inc. is available at http://www.jabber.com/.
 *
 * Portions Copyright (c) 1999-2000 David Waite 
 *
 *   Acknowledgements
 * 
 * Special thanks to the Jabber Open Source Contributors for their
 * suggestions and support of Jabber.
 * 
 *   Changes
 *
 */

package org.jabber.jabberbeans.sax;

import org.jabber.jabberbeans.MessageBuilder;
import org.xml.sax.AttributeList;
import org.xml.sax.SAXException;

/**
 * This is the SubHandler for "&lt;message&gt;" objects. It uses a MessageBuilder
 * object to parse and create Message objects from the incoming XML, and
 * notifies the main bean (MessengerBean) when either a new message arrives,
 * an error arrives on an attempted sent message, or an error arrives in the 
 * server XML.
 * 
 * @author  David Waite <a href="mailto:dwaite@jabber.com">
 *                      <i>&lt;dwaite@jabber.com&gt;</i></a>
 * @author  $Author: mass $
 * @version $Revision: 1.9 $ 
 */

public final class MessageHandler extends PacketSubHandler
{
	/** list of element types specific to &lt;message&gt; packets */
	private static final String elementTypes[]=
	{
		"body",
		"subject",
		"thread"
	};

	/** Creates a new <code>MessageHandler</code> instance. */
	public MessageHandler()
	{
		super();
		builder=new MessageBuilder();
	}

	/** this method verifies that elements are handled by this handler,
	 * returning false if they aren't */
	protected final boolean packetStartElement(String name, AttributeList attributes)
	{
		for (int i=0;i<elementTypes.length;i++)
		{
			if (name.equals(elementTypes[i]))
			{
				elementChars=new StringBuffer();
				return true;
			}
		}
		return false;
	}

	/**
	 * <code>packetEndElement</code> notifies the end of a particular
	 * element type, which is used to register the data in a particular
	 * element with the builder.
	 *
	 * @param name a <code>String</code> holding the element name
	 * @exception SAXException if there is a SAX parsing exception, such
	 *            as a mismatched element tag
	 */
	protected final void packetEndElement(String name) throws SAXException
	{
		if (name.equals(elementTypes[0]))// = body
				((MessageBuilder)builder).setBody(new String(elementChars));

		if (name.equals(elementTypes[1]))// = subject
				((MessageBuilder)builder).setSubject(new String(elementChars));

		if (name.equals(elementTypes[2]))// = thread
				((MessageBuilder)builder).setThread(new String(elementChars));

		//possibly unknown elements, we just ignore them, per spec.
	}
}