/*
 *   License
 *
 * The contents of this file are subject to the Jabber Open Source License
 * Version 1.0 (the "License").  You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License.  You
 * may obtain a copy of the License at http://www.jabber.com/license/ or at
 * http://www.opensource.org/.  
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 *   Copyrights
 *
 * Portions created by or assigned to Jabber.com, Inc. are 
 * Copyright (c) 2000 Jabber.com, Inc.  All Rights Reserved.  Contact
 * information for Jabber.com, Inc. is available at http://www.jabber.com/.
 *
 * Portions Copyright (c) 1999-2000 David Waite 
 *
 *   Acknowledgements
 * 
 * Special thanks to the Jabber Open Source Contributors for their
 * suggestions and support of Jabber.
 * 
 *   Changes
 *
 */

package org.jabber.jabberbeans.sax;

import org.xml.sax.AttributeList;
import org.xml.sax.SAXException;
import org.jabber.jabberbeans.PresenceBuilder;

/**
 * PresenceHandler, which is used to create presence packets
 * 
 * @author  David Waite <a href="mailto:dwaite@jabber.com">
 *                      <i>&lt;dwaite@jabber.com&gt;</i></a>
 * @author  $Author: mass $
 * @version $Revision: 1.8 $ 
 */
public final class PresenceHandler
    extends PacketSubHandler
{
    /** array of elements specific to presence */
    private static final String elementTypes[]=
    {
	"status",
	"priority",
	"show"
    };
 
    /**
     * Creates a new <code>PresenceHandler</code> instance.
     */
    public PresenceHandler()
    {
	super();
	builder= new PresenceBuilder();
    }

    /** this method verifies that elements are handled by this handler,
     * returning false if they aren't */
    protected final boolean packetStartElement(String name, 
					       AttributeList attributes)
    {
	
	for (int i=0;i<elementTypes.length;i++)
	{
	    if (name.equals(elementTypes[i]))
	    {
		elementChars=new StringBuffer();
		return true;
	    }
	}
	return false;
    }
	
    /**
     * handler for types not covered by the base PacketSubHandler
     *
     * @param name string holding the element name
     * @exception SAXException thrown on error
     */
    protected final void packetEndElement(String name)
	throws SAXException
    {
	if (name.equals(elementTypes[0]))// = status
	    ((PresenceBuilder)builder).setStatus(new String(elementChars));
	if (name.equals(elementTypes[1]))// = priority
	    ((PresenceBuilder)builder).setPriority
		(Integer.parseInt(new String(elementChars)));
	if (name.equals(elementTypes[2]))// = show
	    ((PresenceBuilder)builder).setStateShow(new String(elementChars));
    }
}
