/*
 *   License
 *
 * The contents of this file are subject to the Jabber Open Source License
 * Version 1.0 (the "License").  You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License.  You
 * may obtain a copy of the License at http://www.jabber.com/license/ or at
 * http://www.opensource.org/.  
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 *   Copyrights
 *
 * Portions created by or assigned to Jabber.com, Inc. are 
 * Copyright (c) 2000 Jabber.com, Inc.  All Rights Reserved.  Contact
 * information for Jabber.com, Inc. is available at http://www.jabber.com/.
 *
 *   Acknowledgements
 * 
 * Special thanks to the Jabber Open Source Contributors for their
 * suggestions and support of Jabber.
 * 
 *   Changes
 *
 */

package org.jabber.jabberbeans.sax;

import org.jabber.jabberbeans.*;
import org.xml.sax.*;

/**
 * XMLStream error parsing code, used to parse stream:error packets
 * (protocol-level errors)
 * 
 * @author  David Waite <a href="mailto:dwaite@jabber.com">
 *                      <i>&lt;dwaite@jabber.com&gt;</i></a>
 * @author  $Author: mass $
 * @version $Revision: 1.2 $ 
 */
public class XMLStreamErrorHandler
    extends SubHandler
{
    /** element character buffer, used to catch the error content */
    private StringBuffer elementChars;

    /**
     * Creates a new <code>XMLStreamErrorHandler</code> instance.
     */
    public XMLStreamErrorHandler()
    {
	super();
    }

    /**
     * start the stream:error handler
     *
     * @param name element name
     * @param attributes element attributes
     */
    public void startHandler(String name, AttributeList attributes)
    {
	elementChars=new StringBuffer();
    }
	
    /**
     * stops the stream:error handler
     *
     * @param name element name
     */
    public Object stopHandler(String name)
    {
	return new XMLStreamError(new String(elementChars));
    }

    /**
     * handles data characters, by appending them to the elementChars
     * StringBuffer
     *
     * @param ch a <code>char[]</code> value with character data
     * @param start starting offset
     * @param length length from offset
     */
    public void characters(char[] ch, int start, int length)
    {
	elementChars.append(ch,start,length);
    }
}
