/*
 *   License
 *
 * The contents of this file are subject to the Jabber Open Source License
 * Version 1.0 (the "License").  You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License.  You
 * may obtain a copy of the License at http://www.jabber.com/license/ or at
 * http://www.opensource.org/.  
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 *   Copyrights
 *
 * Portions created by or assigned to Jabber.com, Inc. are 
 * Copyright (c) 2000 Jabber.com, Inc.  All Rights Reserved.  Contact
 * information for Jabber.com, Inc. is available at http://www.jabber.com/.
 *
 *   Acknowledgements
 * 
 * Special thanks to the Jabber Open Source Contributors for their
 * suggestions and support of Jabber.
 * 
 *   Changes
 *
 */

package org.jabber.jabberbeans.sax.serverside;

import org.jabber.jabberbeans.sax.SubHandler;
import org.jabber.jabberbeans.serverside.Handshake;
import org.xml.sax.AttributeList;
import org.xml.sax.SAXException;

/**
 * <code>HandshakeHandler</code> is responsible for the generation of
 * <code>Handshake</code> objects from the server stream.
 *
 * @author  David Waite <a href="mailto:dwaite@jabber.com">
 *                      <i>&lt;dwaite@jabber.com&gt;</i></a>
 * @author  $Author: dwaite $
 * @version $Revision: 1.1 $
 */
public class HandshakeHandler
    extends SubHandler
{
    /** stringbuffer for catching the handshake contents.*/
    protected StringBuffer elementChars;
    
    /**
     * Creates a new <code>HandshakeHandler</code> instance.
     *
     */
    public HandshakeHandler()
    {
	super();
	elementChars=null;
    }
    
    protected final void startHandler(String name, AttributeList attributes)
	throws SAXException
    {
	elementChars=new StringBuffer();
    }

    protected final Object stopHandler(String name)
    {
	return new Handshake(new String(elementChars));
    }

    public void characters(char[] ch, int start, int length)
	throws SAXException
    {elementChars.append(ch,start,length);}

}
