/*
 *   License
 *
 * The contents of this file are subject to the Jabber Open Source License
 * Version 1.0 (the "License").  You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License.  You
 * may obtain a copy of the License at http://www.jabber.com/license/ or at
 * http://www.opensource.org/.  
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 *   Copyrights
 *
 * Portions created by or assigned to Jabber.com, Inc. are 
 * Copyright (c) 2000 Jabber.com, Inc.  All Rights Reserved.  Contact
 * information for Jabber.com, Inc. is available at http://www.jabber.com/.
 *
 * Portions Copyright (c) 1999-2000 David Waite 
 *
 *   Acknowledgements
 * 
 * Special thanks to the Jabber Open Source Contributors for their
 * suggestions and support of Jabber.
 * 
 *   Changes
 *
 */

package org.jabber.jabberbeans.sax.serverside;

import org.jabber.jabberbeans.sax.PacketSubHandler;
import org.jabber.jabberbeans.serverside.XDBBuilder;
import org.xml.sax.AttributeList;

/**
 * This is the SubHandler for "<xdb>" objects. It uses a XDBBuilder
 * object to parse and create XDB objects from the incoming XML, and
 * notifies the main bean (ConnectionBean) when either a new packet arrives,
 * an error arrives on an attempted sent message, or an error arrives in the 
 * server XML.
 * 
 * @author  David Waite <a href="mailto:dwaite@jabber.com">
 *                      <i>&lt;dwaite@jabber.com&gt;</i></a>
 * @author  $Author: mass $
 * @version $Revision: 1.5 $ 
 */

public final class XDBHandler
    extends PacketSubHandler
{
    /**
     * Creates a new <code>XDBHandler</code> instance.
     */
    public XDBHandler()
    {
	super();
	builder=new XDBBuilder();
    };

    protected void packetStartHandler(String name, AttributeList attributes)
    {
	((XDBBuilder)builder).setErrorText(attributes.getValue("error"));
	((XDBBuilder)builder).setNamespace(attributes.getValue("ns"));
	((XDBBuilder)builder).setAction(attributes.getValue("action"));
	((XDBBuilder)builder).setMatch(attributes.getValue("match"));
    }
}
