/*
 *   License
 *
 * The contents of this file are subject to the Jabber Open Source License
 * Version 1.0 (the "License").  You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License.  You
 * may obtain a copy of the License at http://www.jabber.com/license/ or at
 * http://www.opensource.org/.  
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 *   Copyrights
 *
 * Portions created by or assigned to Jabber.com, Inc. are 
 * Copyright (c) 2000 Jabber.com, Inc.  All Rights Reserved.  Contact
 * information for Jabber.com, Inc. is available at http://www.jabber.com/.
 *
 *   Acknowledgements
 * 
 * Special thanks to the Jabber Open Source Contributors for their
 * suggestions and support of Jabber.
 * 
 *   Changes
 *
 */

package org.jabber.jabberbeans.serverside;

import org.jabber.jabberbeans.*;

/**
 * a <code>Handshake</code> is used during the authentication process of a component communicating via TCP.
 * 
 * The contents are a SHA1 hash of a 'seed' value sent as an id, and a 'secret' known by the component and server.
 * The code to generate this hash is external to this representation class.
 *
 * @author  David Waite <a href="mailto:dwaite@jabber.com">
 *                      <i>&lt;dwaite@jabber.com&gt;</i></a>
 * @author  $Author: mass $
 * @version $Revision: 1.2 $
 */
public class Handshake extends XMLData implements Packet
{
	/** content string */
	private String handshake;


	/**
	 * Creates a new <code>Handshake</code> instance.
	 *
	 * @param handshake a <code>String</code> value, the contents of the handshake
	 */
	public Handshake(String handshake)
	{
		this.handshake = handshake;
		if(this.handshake == null)
			this.handshake = "";
	}

	/**
	 * <code>getContent</code> returns the handshake value
	 *
	 * @return a <code>String</code> value
	 */
	public String getContent()
	{
		return handshake;
	}

	/**
	 * <code>appendItem</code> appends the XML representation of the
	 * current packet data to the specified <code>StringBuffer</code>.
	 *
	 * @param retval The <code>StringBuffer</code> to append to
	 */
	public void appendItem(StringBuffer retval)
	{
		retval.append("<handshake");
		if(handshake == null)
		{
			retval.append("/>");
			return;
		}

		retval.append('>');
		retval.append(handshake);
		retval.append("</handshake>");	
	}
}