/*
 *   License
 *
 * The contents of this file are subject to the Jabber Open Source License
 * Version 1.0 (the "License").  You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License.  You
 * may obtain a copy of the License at http://www.jabber.com/license/ or at
 * http://www.opensource.org/.  
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 *   Copyrights
 *
 * Portions created by or assigned to Jabber.com, Inc. are 
 * Copyright (c) 2000 Jabber.com, Inc.  All Rights Reserved.  Contact
 * information for Jabber.com, Inc. is available at http://www.jabber.com/.
 *
 *   Acknowledgements
 * 
 * Special thanks to the Jabber Open Source Contributors for their
 * suggestions and support of Jabber.
 * 
 *   Changes
 *
 */

package org.jabber.jabberbeans.serverside;

import org.jabber.jabberbeans.*;
import org.jabber.jabberbeans.Extension.*;
import java.util.Vector;
import java.io.Serializable;

/**
 * A <code>Route</code> object represents a single route packet, which is 
 * a wrapper used to direct basic jabber client packets (<message>.<presence>.<iq>)
 * into a specific server-side component
 *<p>
 *
 * @see ContentPacket
 *
 * @author  David Waite <a href="mailto:dwaite@jabber.com">
 *                      <i>&lt;dwaite@jabber.com&gt;</i></a>
 * @author  $Author: mass $
 * @version $Revision: 1.4 $
 */
public class Route
    extends ContentPacket
{
    /**
     * Creates a new <code>InfoQuery</code> instance. Note that because of
     * the complexity of the InfoQuery object and because the object is
     * immutable after creation, a builder object is needed in order to
     * construct this object.
     *
     * @param builder an <code>InfoQueryBuilder</code> holding appropriate
     * values
     * @exception InstantiationException if the values supplied by the
     * InfoQueryBuilder are not sufficient to creaate a 'correctly-formed'
     * InfoQuery packet.
     */
    public Route(RouteBuilder builder)
        throws InstantiationException
    {
        super((PacketBuilder)builder);

        if (extensions.size()>1) 
            throw new InstantiationException("Route allows up to " + 
                                             "one extension");    
        if (extensions.size()==0) 
	    return;
    }

    /**
     * <code>appendItem</code> appends the XML representation of the
     * current packet data to the specified <code>StringBuffer</code>.
     *
     * @param retval The <code>StringBuffer</code> to append to
     */
    public void appendItem(StringBuffer retval)
    {
	retval.append("<route");
        //append contentPacket attributes.
        appendBaseAttribs(retval);
	appendAttrib(retval, "error", this.getErrorText());
        retval.append(">"); 
        if (extensions.size()>0)
            ((Extension)extensions.firstElement()).appendItem(retval);

        retval.append("</route>");
    }
}
