/*
 *   License
 *
 * The contents of this file are subject to the Jabber Open Source License
 * Version 1.0 (the "License").  You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License.  You
 * may obtain a copy of the License at http://www.jabber.com/license/ or at
 * http://www.opensource.org/.  
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 *   Copyrights
 *
 * Portions created by or assigned to Jabber.com, Inc. are 
 * Copyright (c) 2000 Jabber.com, Inc.  All Rights Reserved.  Contact
 * information for Jabber.com, Inc. is available at http://www.jabber.com/.
 *
 *   Acknowledgements
 * 
 * Special thanks to the Jabber Open Source Contributors for their
 * suggestions and support of Jabber.
 * 
 *   Changes
 *
 */

package org.jabber.jabberbeans.serverside;

import org.jabber.jabberbeans.*;
import org.jabber.jabberbeans.Extension.*;
import java.io.Serializable;

/**
 * <code>RouteBuilder</code> is the class that expands upon PacketBuilder
 * to allow building of route objects (packets). The builder is a required
 * object in the creation of said packet, as the number of fields is too 
 * numerous to make direct creation feasable and non-error prone.
 *
 * @author  David Waite <a href="mailto:dwaite@jabber.com">
 *                      <i>&lt;dwaite@jabber.com&gt;</i></a>
 * @author  $Author: mass $
 * @version $Revision: 1.2 $
 */
public class RouteBuilder
    extends PacketBuilder
    implements Serializable
{
    /** Creates a new <code>InfoQueryBuilder</code> instance. */
    public RouteBuilder()
    { reset(); }

    /**
     * <code>reset</code> all parameters (including those in the parent class)
     * to default values
     */
    public void reset()
    { resetBase(); }

    /**
     * Add an extension to this object
     *
     * @param p a <code>Packet</code> value
     */
    public void addPacket(Packet p)
    {
        if (!extensions.contains(p))
            extensions.addElement(p);
    }

    /**
     * Remove an extension from this object
     *
     * @param e a <code>Packet</code> value
     */
    public void delPacket(Packet p)
    {
        if (extensions.contains(p))
            extensions.removeElement(p);
    }

    /**
     * <code>build</code> returns a packet, specifically an InfoQuery packet.
     * It will fail if the parameters specified in the builder were not
     * sufficient to create a valid packet.
     *
     * @return a valid <code>Packet</code>
     * @exception InstantiationException if there was not sufficient 
     * information to create a valid InfoQuery packet
     */
    public Packet build()
        throws InstantiationException
    { return new Route(this); }
}
