/*
 *   License
 *
 * The contents of this file are subject to the Jabber Open Source License
 * Version 1.0 (the "License").  You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License.  You
 * may obtain a copy of the License at http://www.jabber.com/license/ or at
 * http://www.opensource.org/.  
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 *   Copyrights
 *
 * Portions created by or assigned to Jabber.com, Inc. are 
 * Copyright (c) 2000 Jabber.com, Inc.  All Rights Reserved.  Contact
 * information for Jabber.com, Inc. is available at http://www.jabber.com/.
 *
 *   Acknowledgements
 * 
 * Special thanks to the Jabber Open Source Contributors for their
 * suggestions and support of Jabber.
 * 
 *   Changes
 *
 */

package org.jabber.jabberbeans.serverside;

import org.jabber.jabberbeans.*;
import org.jabber.jabberbeans.Extension.*;
import java.util.Vector;
import java.io.Serializable;

/**
 * A <code>XDB12</code> object represents a single XDB packet for the 1.2
 * version of the server. This XDB Packet is used to set and query 
 * information between the server components and any data store<p>
 * <i>e.g.:</i><br>
 * &lt;xdb type="get|set|result|error" to="user@service/namespage"&gt;<br>
 * &nbsp;&nbsp;&lt;query xmlns="namespace"&gt;<br>
 * &nbsp;&nbsp;&nbsp;&nbsp;<i>information custom to the namespace..</i><br>
 * &nbsp;&nbsp;&lt;/query&gt;<br>
 * &lt;xdb&gt;<p>
 * 
 * Note that unlike other basic packet types, XDB does not do any error
 * responses. If there is a problem, the jabber server will retry events
 * until the client component times out. To report errors, use &lt;log&gt;
 * packets.
 *
 * @see ContentPacket
 *
 * @author  David Waite <a href="mailto:dwaite@jabber.com">
 *                      <i>&lt;dwaite@jabber.com&gt;</i></a>
 * @author  $Author: mass $
 * @version $Revision: 1.2 $
 */
public class XDB12
    extends ContentPacket
{
    /**
     * Creates a new <code>InfoQuery</code> instance. Note that because of
     * the complexity of the InfoQuery object and because the object is
     * immutable after creation, a builder object is needed in order to
     * construct this object.
     *
     * @param builder an <code>InfoQueryBuilder</code> holding appropriate
     * values
     * @exception InstantiationException if the values supplied by the
     * InfoQueryBuilder are not sufficient to creaate a 'correctly-formed'
     * InfoQuery packet.
     */
    public XDB12(XDB12Builder builder)
        throws InstantiationException
    {
        super((PacketBuilder)builder);

        if (extensions.size()>1) 
            throw new InstantiationException("XDB allows up to " + 
                                             "one extension");    
        if (extensions.size()==0) 
	    return;
    }

    /**
     * <code>appendItem</code> appends the XML representation of the
     * current packet data to the specified <code>StringBuffer</code>.
     *
     * @param retval The <code>StringBuffer</code> to append to
     */
    public void appendItem(StringBuffer retval)
    {
	retval.append("<xdb");
        //append contentPacket attributes.
        appendBaseAttribs(retval);

        retval.append(">"); 
        if (extensions.size()>0)
            ((Extension)extensions.firstElement()).appendItem(retval);

        retval.append("</xdb>");
    }
}
