/*
 *   License
 *
 * The contents of this file are subject to the Jabber Open Source License
 * Version 1.0 (the "License").  You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License.  You
 * may obtain a copy of the License at http://www.jabber.com/license/ or at
 * http://www.opensource.org/.  
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 *   Copyrights
 *
 * Portions created by or assigned to Jabber.com, Inc. are 
 * Copyright (c) 2000 Jabber.com, Inc.  All Rights Reserved.  Contact
 * information for Jabber.com, Inc. is available at http://www.jabber.com/.
 *
 * Portions Copyright (c) 1999-2000 David Waite 
 *
 *   Acknowledgements
 * 
 * Special thanks to the Jabber Open Source Contributors for their
 * suggestions and support of Jabber.
 * 
 *   Changes
 *
 */

package org.jabber.jabberbeans.util;

import org.jabber.jabberbeans.*;

/**
 * <code>PacketDebug</code> is a dirt-simple, yet very useful, class to
 * debug connection data. It prints out any sent or received data over
 * the pipe, along with the object classname.
 *
 * @author <a href="mailto:dwaite@jabber.com">
 *         <i>&lt;dwaite@jabber.com&gt;</i></a>
 * @author  $Author: dwaite $
 * @version $Revision: 1.2 $
 */
public  class PacketDebug
    implements PacketListener
{
    /** prints out a debug message on packet receipt (after data has been 
     * received and successfully parsed) 
     */
    public final void receivedPacket(PacketEvent pe)
    {
	System.err.println("received a packet! :\n   " + 
	    pe.getPacket().getClass().getName() + "\n    " +
	    pe.getPacket().toString());
    }

    /** prints out a debug message on packet sending (after send method 
     * has been called and the flush on the output stream completes)
     */
    public final void sentPacket(PacketEvent pe)
    {
	System.err.println("sent a packet! :\n   " + 
			   pe.getPacket().getClass().getName() + "\n    " +
			   pe.getPacket().toString());
    }

    /** prints out a debug message on packet sending failure */
    public final void sendFailed(PacketEvent pe)
    {
	System.err.println("send failed on packet:\n   " +
			   pe.getPacket().getClass().getName() + "\n    " +
			   pe.getPacket().toString());
    }
}
